package com.xx.merchanthbh.ui.appeal;

import android.app.Application;
import android.util.Log;
import android.view.View;

import androidx.annotation.NonNull;
import androidx.databinding.ObservableField;
import androidx.lifecycle.MutableLiveData;

import com.xx.merchanthbh.data.http.requst.AppealRequest;
import com.xx.merchanthbh.data.http.respons.AppealBean;
import com.xx.merchanthbh.data.http.respons.AppealFilesBean;
import com.xx.merchanthbh.data.http.respons.Filebean;
import com.xx.merchanthbh.data.http.respons.RejectionBean;
import com.xx.merchanthbh.data.local.LocalData;
import com.xx.merchanthbh.data.staticdata.StaticData;
import com.xx.xxviewlibrary.utils.AddImgAdapter;

import java.util.List;

import io.reactivex.rxjava3.disposables.Disposable;
import io.reactivex.rxjava3.functions.Consumer;
import me.goldze.mvvmhabit.base.BaseViewModel;
import me.goldze.mvvmhabit.http.ApiDisposableObserver;
import me.goldze.mvvmhabit.utils.RxUtils;

public class AppealDetailViewModel extends BaseViewModel<AppealRequest> {

    //    创建诉求详情实体对象
    public MutableLiveData<List<Filebean>> AppealDetailList = new MutableLiveData<>();
    /*反馈人*/
    public ObservableField<String> appealPerson = new ObservableField<>("");
    /*诉求商户*/
    public ObservableField<String> appealCustom = new ObservableField<>("");
    /*联系方式*/
    public ObservableField<String> appealPhone = new ObservableField<>("");
    /*文字描述*/
    public ObservableField<String> appealDescribe = new ObservableField<>("");
    /*上传图片描述*/
    public ObservableField<String> imageFile = new ObservableField<>("");
    /*上传图片*/
    public AddImgAdapter appealPicsAdapter;

    /*驳回原因*/
    public MutableLiveData<String> remark = new MutableLiveData<>(null);
    //展示驳回原因弹窗
    public MutableLiveData<RejectionBean> showRejectionDialog = new MutableLiveData<>();


    public AppealDetailViewModel(@NonNull Application application) {
        super(application);
    }

    public AppealDetailViewModel(@NonNull Application application, AppealRequest model) {
        super(application, model);
    }

    private void setValueToNickName() {
        /*给登录人所在商户赋值*/
        appealCustom.set(LocalData.getMerchant().getStoreName());
        /*给登录人赋值*/
        appealPerson.set(LocalData.getUser().getNickName());
    }

    public void refreshNickName() {
        setValueToNickName();
    }

    /*获取诉求详情*/
    public void getAppealDetailById(String id) {
        model.getAppealDetailById(id)
                .compose(RxUtils.schedulersTransformer()) //线程调度
                .doOnSubscribe(AppealDetailViewModel.this)
                .doOnSubscribe(new Consumer<Disposable>() {
                    @Override
                    public void accept(Disposable disposable) throws Exception {
                    }
                }).subscribe(new ApiDisposableObserver<AppealBean>() {
                    @Override
                    public void onSuccess(AppealBean resultBean) {
                        try {
                            /*存值*/
                            AppealDetailList.postValue(resultBean.getAppealFiles());
                            /*反馈人*/
                            appealPerson.set(resultBean.getFeedbackPerson());
                            /*联系方式*/
                            appealPhone.set(resultBean.getContactMode());
                            /*描述*/
                            appealDescribe.set(resultBean.getLiteralDescription());
                            /*所属商户*/
                            appealCustom.set(resultBean.getMerchant().getCompanyName());
                            /*驳回原因赋值*/
                            if (resultBean.getAppealStatus().equals("REJECTED") && !resultBean.getOperations().isEmpty()) {
                                /*取操作日志最新的一条的remark*/
                                remark.setValue(resultBean.getOperations().get(1).getRemark());
                            }
                            /*上传图片*/
                            if (!resultBean.getAppealFiles().isEmpty()) {
                                imageFile.set(String.valueOf(resultBean.getAppealFiles().get(0).getFilePath()));
                                if (imageFile.get() != null) {
                                    Log.d("有路径有路径", "onSuccess: hhhhhhhhh");
                                    StaticData.imageFilesData = 0;
                                } else {
                                    StaticData.imageFilesData = 1;
                                    throw new NullPointerException("imageFile为空");
                                }
                            } else {
                                StaticData.imageFilesData = 1;
                            }
                        } catch (IndexOutOfBoundsException e) {
                            onError(e);
                        } catch (NullPointerException e) {
                            onError(e);
                        }
                    }

                    @Override
                    public void onError(String Error) {
                        dismissDialog();
                    }
                });
    }

    /*查看原因的弹窗*/
    public void openReason(View view) {
        boolean deFlag = true;
        RejectionBean rejectionBean = new RejectionBean(deFlag,remark.getValue());
        showRejectionDialog.postValue(rejectionBean);
    }


}
