package com.xx.merchanthbh.ui.appeal;

import android.app.Application;
import android.text.TextUtils;
import android.view.View;

import androidx.annotation.NonNull;
import androidx.databinding.ObservableField;

import com.huantansheng.easyphotos.callback.SelectCallback;
import com.huantansheng.easyphotos.models.album.entity.Photo;
import com.xx.merchanthbh.data.http.requst.AppealRequest;
import com.xx.merchanthbh.data.http.respons.AppealTypeBean;
import com.xx.merchanthbh.data.http.respons.Filebean;
import com.xx.merchanthbh.data.local.LocalData;
import com.xx.merchanthbh.dialog.AppealTypeListDialog;
import com.xx.merchanthbh.dialog.data.TextListProvider;
import com.xx.merchanthbh.ui.appeallist.AppealListActivity;
import com.xx.merchanthbh.ui.appeallist.AppealListViewModel;
import com.xx.xxviewlibrary.base.xxBaseDialog;
import com.xx.xxviewlibrary.utils.AddImgAdapter;
import com.xx.xxviewlibrary.witget.model.FileBean;

import java.io.File;
import java.util.ArrayList;
import java.util.List;
import java.util.stream.Collectors;

import io.reactivex.rxjava3.disposables.Disposable;
import io.reactivex.rxjava3.functions.Consumer;
import me.goldze.mvvmhabit.base.BaseViewModel;
import me.goldze.mvvmhabit.http.ApiDisposableObserver;
import me.goldze.mvvmhabit.utils.RxUtils;
import me.goldze.mvvmhabit.utils.StringUtils;
import me.goldze.mvvmhabit.utils.ToastUtils;

public class AppealViewModel extends BaseViewModel<AppealRequest> {
    /*创建反馈类型数据字典实体对象*/
    public List<AppealTypeBean> appealTypeBeanList = new ArrayList<>();
    /*创建反馈类型的label*/
    public ObservableField<String> dictLabel = new ObservableField<>("");
    /*创建反馈类型的sort*/
    public String dictSort = null;
    /*诉求商户*/
    public ObservableField<String> appealCustom = new ObservableField<>("");
    /*反馈人*/
    public ObservableField<String> appealPerson = new ObservableField<>("");
    /*联系方式*/
    public ObservableField<String> appealPhone = new ObservableField<>("");
    /*文字描述*/
    public ObservableField<String> appealDescribe = new ObservableField<>("");
    /*上传图片*/
    public AddImgAdapter appealPicsAdapter;

    public AppealViewModel(@NonNull Application application) {
        super(application);
    }

    public AppealViewModel(@NonNull Application application, AppealRequest model) {
        super(application, model);
    }

    private void setValueToNickName() {
        /*给登录人所在商户赋值  公司名字*/
        appealCustom.set(LocalData.getMerchant().getCompanyName());
        /*给登录人赋值*/
        appealPerson.set(LocalData.getUser().getNickName());
        /*给登录人联系方式赋值*/
        appealPhone.set(LocalData.getUser().getPhonenumber());
    }
    /*返回列表页*/
    public void clickAppealList(View view) {
        finish();
        /*跳转列表页*/
        startActivity(AppealListActivity.class);
    }
    public void refreshNickName() {
        setValueToNickName();
    }

    /*获取反馈类型列表(数据字典)*/
    public void getAppealTypesList() {
        model.getAppealTypeList()
                .compose(RxUtils.schedulersTransformer()) //线程调度
                .doOnSubscribe(AppealViewModel.this)
                .doOnSubscribe(new Consumer<Disposable>() {
                    @Override
                    public void accept(Disposable disposable) throws Exception {
                    }
                }).subscribe(new ApiDisposableObserver<List<AppealTypeBean>>() {
                    @Override
                    public void onSuccess(List<AppealTypeBean> resultBean) {
                        /*清空反馈类型数据列表*/
                        appealTypeBeanList.clear();
                        /*将接口的数据字典放入*/
                        appealTypeBeanList.addAll(resultBean);
                        /*在初始页面的时候要给选择器(反馈类型)一个初始值*/
                        dictLabel.set(resultBean.get(0).getDictLabel());
                        dictSort = resultBean.get(0).getDictSort();
                    }

                    @Override
                    public void onError(String Error) {
                        dismissDialog();
                    }
                });
    }

    /*反馈类型选择*/
    public void openType(View view) {
        /*创建弹窗的adapter遍历*/
        AppealTypeListDialog dialoh = new AppealTypeListDialog(view.getContext(), appealTypeBeanList);
        dialoh.setDialogClickListener(new xxBaseDialog.onDialogClickListener<TextListProvider>() {
            /*最后点击确定以后执行set*/
            @Override
            public void dialogClickBack(int code, TextListProvider data) {
                /*判空*/
                if (data!=null){
                    /*选择以后把所在的label给set进去*/
                    dictLabel.set(data.providerText());
                    /*选择以后把所在的value给set进去*/
                    dictSort = data.ProviderId();
                }
            }
        });
        /*展示弹窗*/
        dialoh.show();
    }


    /*上传图片*/
    public void openPhoto(AddImgAdapter type, int position) {


        int max = 1;
        if (TextUtils.isEmpty(appealPicsAdapter.mList.get(position).getId())) {
            max = 5 - appealPicsAdapter.getItemCount() + 1;
        }


        startPhotoPage(true, max,"申请的是摄像头和照片视频读取权限，用于在添诉求场景中读取和写入相册和文件内容",new SelectCallback() {
            @Override
            public void onResult(ArrayList<Photo> photos, boolean isOriginal) {
                List<File> fList = new ArrayList<>();
                for (Photo p : photos) {
                    fList.add(new File(p.path));
                }

                model.upLoadFiles(fList).compose(RxUtils.schedulersTransformer()) //线程调度
                        .doOnSubscribe(AppealViewModel.this)
                        .doOnSubscribe(new Consumer<Disposable>() {
                            @Override
                            public void accept(Disposable disposable) throws Exception {

                            }
                        }).subscribe(new ApiDisposableObserver<List<Filebean>>() {
                            @Override
                            public void onSuccess(List<Filebean> resultBean) {

                                if (TextUtils.isEmpty(type.mList.get(position).getId())) {

                                    List<FileBean> fList = new ArrayList<>();
                                    for (Filebean fb : resultBean) {
                                        fList.add(new FileBean(fb.getBusinessId(), fb.getUrl()));
                                    }
                                    type.addImg(fList);
                                } else {
                                    type.mList.get(position).setId(resultBean.get(0).getBusinessId());
                                    type.mList.get(position).setPath(resultBean.get(0).getUrl());
                                }

                                type.notifyDataSetChanged();
                            }

                            @Override
                            public void onError(String Error) {
                                dismissDialog();
                            }


                        });
            }

            @Override
            public void onCancel() {

            }
        });
    }

    private boolean isSubmitting = false; // 添加标志位

    /*最后的提交创建诉求*/
    public void submitAppeal(View view) {
        if (isSubmitting) {
            return; // 如果正在提交诉求，则直接返回，不执行后续操作
        }

        if (StringUtils.isEmpty(appealPhone.get()))
        {
            ToastUtils.showShort("请输入联系方式");
            return;
        }

        isSubmitting = true; // 设置正在提交诉求的标志位为true
        view.setEnabled(false); // 禁用提交按钮，避免快速点击导致重复提交诉求
        /*上传图片*/
        if (isSubmitting == true) {
            /*把图片转成list<String>类型*/
            List<String> uploadImgs = null;
            if (android.os.Build.VERSION.SDK_INT >= android.os.Build.VERSION_CODES.N) {
                uploadImgs = appealPicsAdapter.mList.stream()
                        .map(fileBean -> fileBean.getId())
                        .collect(Collectors.toList());



                /*依次传入反馈类型,诉求商户,反馈人,联系方式,文字描述,上传图片*/
                /*调用request的添加接口*/
                model.addAppeal(dictSort, appealPerson.get().equals("")?null : appealPerson.get(), appealPhone.get(), appealDescribe.get(), uploadImgs).compose(RxUtils.schedulersTransformer()) //线程调度
                        .doOnSubscribe(AppealViewModel.this)
                        .doOnSubscribe(new Consumer<Disposable>() {
                            @Override
                            public void accept(Disposable disposable) throws Exception {

                            }
                        }).subscribe(new ApiDisposableObserver<Boolean>() {
                            @Override
                            public void onSuccess(Boolean resultBean) {
                                ToastUtils.showShort("创建成功!");
                                finish();
                                /*跳转列表页*/
                                startActivity(AppealListActivity.class);
                                isSubmitting = false; // 提交成功后，将标志位设置为false
                            }

                            @Override
                            public void onError(String Error) {
                                isSubmitting = false; // 提交成功后，将标志位设置为false
                            }
                        });
            }
        }

    }




}
