package com.xx.merchanthbh.ui.appeallist

import android.app.ActionBar.LayoutParams
import android.content.Context
import android.content.Intent
import android.os.Handler
import android.util.Log
import android.view.View
import android.widget.ImageView
import com.bumptech.glide.Glide
import com.bumptech.glide.load.resource.bitmap.RoundedCorners
import com.bumptech.glide.request.RequestOptions
import com.stfalcon.imageviewer.StfalconImageViewer
import com.stfalcon.imageviewer.loader.ImageLoader
import com.xx.merchanthbh.R
import com.xx.merchanthbh.data.http.respons.AppealListBean
import com.xx.merchanthbh.databinding.ItemAppealListBinding
import com.xx.merchanthbh.ui.appeal.AppealDetailActivity
import com.xx.merchanthbh.ui.appeal.AppealEditActivity
import com.xx.xxviewlibrary.base.xxBaseRecyclerViewAdapter
import com.xx.xxviewlibrary.base.xxBaseRecyclerViewAdapter.OnItemClick
import me.jessyan.autosize.utils.AutoSizeUtils

class AppealListAdapter(context: Context) :
    xxBaseRecyclerViewAdapter<ItemAppealListBinding, AppealListBean>(context),
    OnItemClick<AppealListBean> {

    init {
        itemClick = this
    }

    override fun initLayout(): Int {
        return R.layout.item_appeal_list
    }

    override fun covert(dataBind: ItemAppealListBinding?, data: AppealListBean?, position: Int) {
        dataBind?.data = data
        dataBind?.numTitle = "诉求单号："

        when (data?.appealStatus) {
            "COMPLETED" -> {
                dataBind?.tvIalStatic?.setText("已完成")
                dataBind?.tvIalStatic?.setTextColor(mContext.getColor(R.color.text_foreground))
                dataBind?.btnIalEdit?.visibility = View.GONE
            }

            "PROCESSING" -> {
                dataBind?.tvIalStatic?.setText("处理中")
                dataBind?.tvIalStatic?.setTextColor(mContext.getColor(R.color.static_deal))
                dataBind?.btnIalEdit?.visibility = View.GONE
            }

            "TO_BE_ALLOT" -> {
                dataBind?.tvIalStatic?.setText("待分配")
                dataBind?.tvIalStatic?.setTextColor(mContext.getColor(R.color.text_foreground))
                dataBind?.btnIalEdit?.visibility = View.GONE
            }

            "REJECTED" -> {
                dataBind?.tvIalStatic?.setText("已驳回")
                dataBind?.tvIalStatic?.setTextColor(mContext.getColor(R.color.static_reject))
                dataBind?.btnIalEdit?.visibility = View.VISIBLE
            }
        }
        dataBind?.llIalImgs?.removeAllViews()
        /*靠下标取图*/
        for ((index, file) in data?.appealFiles!!.withIndex()) {
            var iv = ImageView(mContext)
            var lp: LayoutParams = LayoutParams(
                AutoSizeUtils.dp2px(mContext, 70.5f),
                AutoSizeUtils.dp2px(mContext, 70.5f)
            )
            lp.setMargins(0, 0, AutoSizeUtils.dp2px(mContext, 10.0f), 0)
            iv.layoutParams = lp
            val options: RequestOptions = RequestOptions
                .bitmapTransform(RoundedCorners(AutoSizeUtils.dp2px(mContext, 12f)))
            Glide.with(mContext).asBitmap()
                .apply(options)
                .load(file.url)
                .into(iv)
            dataBind?.llIalImgs?.addView(iv)

            // 设置点击事件监听器
            iv.tag = index // 设置Tag为position的值
            iv.setOnClickListener(View.OnClickListener { view ->
                if (data != null) {
                    val position = view.tag as Int // 获取position的值
                    // 图片放大
                    StfalconImageViewer.Builder<AppealListBean?>(mContext, mList) { imageView: ImageView?, image: AppealListBean? ->
                            Glide.with(mContext)
                                .load(file.url).into(
                                    imageView!!
                                )
                        }.withStartPosition(position).show()
                    Log.v("诉求列表位置是几啊", position.toString())
                }
            })
        }

        dataBind?.btnIalEdit?.setOnClickListener()
        {
            val intent = Intent(mContext, AppealEditActivity::class.java)
            intent.putExtra("appealId", data.businessId)
            mContext.startActivity(intent)
        }
    }

    /*设标志位防止快速点击会连续打开多个详情页*/
    private var isClickable = true

    override fun itemClickCalBack(position: Int, data: AppealListBean?) {
        if (isClickable) {
            isClickable = false

            val intent = Intent(mContext, AppealDetailActivity::class.java)
            intent.putExtra("appealId", data?.businessId)
            mContext.startActivity(intent)

            /*设一个定时*/
            Handler().postDelayed({
                isClickable = true
            }, 1000) // 延时时间为1秒，可以根据实际情况调整
        }
    }
}