package com.xx.merchanthbh.ui.assistant;

import android.app.Application;
import android.graphics.drawable.Drawable;
import android.util.Log;
import android.view.View;

import androidx.annotation.NonNull;
import androidx.databinding.ObservableField;
import androidx.lifecycle.MutableLiveData;

import com.xx.merchanthbh.activity.adapter.AssistantInformationAdapter;
import com.xx.merchanthbh.data.http.requst.AssistantManagementRequest;
import com.xx.merchanthbh.data.http.respons.ActivityCenterBean;
import com.xx.merchanthbh.data.http.respons.AssistantInformationBean;
import com.xx.merchanthbh.data.http.respons.Filebean;
import com.xx.merchanthbh.data.staticdata.StaticData;
import com.xx.merchanthbh.ui.merchantenter.MerchantEnterViewModel;
import com.xx.xxviewlibrary.comm.CommTextDialog;
import com.xx.xxviewlibrary.comm.RefuseDialogBean;

import java.util.ArrayList;
import java.util.List;

import io.reactivex.rxjava3.disposables.Disposable;
import io.reactivex.rxjava3.functions.Consumer;
import me.goldze.mvvmhabit.base.BaseViewModel;
import me.goldze.mvvmhabit.base.ListBaseViewModel;
import me.goldze.mvvmhabit.binding.command.BindingAction;
import me.goldze.mvvmhabit.binding.command.BindingCommand;
import me.goldze.mvvmhabit.http.ApiDisposableObserver;
import me.goldze.mvvmhabit.http.ApiDisposablePageObserver;
import me.goldze.mvvmhabit.utils.RxUtils;

public class AssistantManagementViewModel extends ListBaseViewModel<AssistantManagementRequest> {

    public String oldSearch="";
    //搜索内容绑定
    public ObservableField<String> searchWord = new ObservableField<>("");

//    public ObservableField<Drawable> addImg = new ObservableField<>(null);
/*实体类对象*/
    public MutableLiveData<List<AssistantInformationBean>> assistantInformationList = new MutableLiveData<>(new ArrayList<>());

    public AssistantManagementViewModel(@NonNull Application application) {
        super(application);
    }

    public AssistantInformationAdapter adapter;

    public AssistantManagementViewModel(@NonNull Application application, AssistantManagementRequest model) {
        super(application, model);
    }

    //跳转新建店员
    public View.OnClickListener goAssistantAdd = new View.OnClickListener() {
        @Override
        public void onClick(View view) {
            startActivity(AssistantAddActivity.class);
        }
    };


    //搜索店员列表
    public BindingCommand goAssistantMsg = new BindingCommand(new BindingAction() {
        @Override
        public void call() {
            if (oldSearch.equals(searchWord.get()))
            {
                return;
            }
            oldSearch=searchWord.get();
            Log.v("搜索的字段",oldSearch);

            geAssistantList();
        }

    });
    //    店员列表赋值
    public void geAssistantList() {
        if (!searchWord.get().isEmpty()){
            adapter.mList.clear();
            page=1;
            // 重置 loadMoreStatic
            loadMoreStatic.postValue(0);
        }
        model.getAssistantList(searchWord.get(),page).compose(RxUtils.schedulersTransformer()) //线程调度
                .doOnSubscribe(AssistantManagementViewModel.this)
                .doOnSubscribe (new Consumer<Disposable>() {
                    @Override
                    public void accept(Disposable disposable) throws Exception {
                        showDialog("请稍等");
                    }
                }).subscribe(new ApiDisposablePageObserver<AssistantInformationBean>() {
                    @Override
                    public void onSuccess(List<AssistantInformationBean> resultBean) {

                        dismissDialog();
                        if (page == 1) {
                            adapter.mList = resultBean;
                        } else {
                            adapter.mList.addAll(resultBean);

                        }
                        adapter.notifyDataSetChanged();
                    }
                    @Override
                    public void onError(String Error) {
                        dismissDialog();
                    }

                    @Override
                    public void getTotal(int total) {
                        if (total==0)
                        {
                            loadMoreStatic.postValue(3);
                        }else if (adapter.mList.size()>=total)
                        {
                            loadMoreStatic.postValue(2);
                        }else {
                            loadMoreStatic.postValue(1);
                        }
                    }

                });
    }

    public void deleteAssistant(AssistantInformationBean bean) {
        showCommTextDialog(new RefuseDialogBean("是否确认删除店员" + bean.getShopAssistantName(), "确定", "取消", "删除店员"), new CommTextDialog.onAcceptCallBack() {
            @Override
            public void acceptBack() {
                model.deleteAssistant(bean.getBusinessId()).compose(RxUtils.schedulersTransformer()) //线程调度
                        .doOnSubscribe(AssistantManagementViewModel.this)
                        .doOnSubscribe (new Consumer<Disposable>() {
                            @Override
                            public void accept(Disposable disposable) throws Exception {
//                        showDialog("请稍等");
                            }
                        }).subscribe(new ApiDisposableObserver<Boolean>() {
                            @Override
                            public void onSuccess(Boolean resultBean) {


                                adapter.mList.remove(bean);


                                adapter.notifyDataSetChanged();
                            }

                            @Override
                            public void onError(String Error) {
                                dismissDialog();
                            }

                        });
            }

            @Override
            public void refuseBack() {

            }
        });

    }
}
