package com.xx.merchanthbh.ui.electric

import android.Manifest
import android.content.Intent
import android.net.Uri
import android.os.Bundle
import android.text.Editable
import android.text.TextUtils
import android.text.TextWatcher
import android.view.View
import androidx.recyclerview.widget.RecyclerView
import com.bumptech.glide.Glide
import com.bumptech.glide.load.resource.bitmap.RoundedCorners
import com.xx.merchanthbh.BR
import com.xx.merchanthbh.R
import com.xx.merchanthbh.data.http.requst.ElectricPayRequest
import com.xx.merchanthbh.data.staticdata.StaticData
import com.xx.merchanthbh.databinding.ActivityElectricPayBinding
import io.reactivex.rxjava3.core.Observer
import io.reactivex.rxjava3.disposables.Disposable
import me.goldze.mvvmhabit.base.BaseActivity
import me.goldze.mvvmhabit.utils.ToastUtils

class ElectricPayActivity : BaseActivity<ActivityElectricPayBinding, ElectricPayViewModel>() {

    var prices: MutableList<Int> = arrayListOf<Int>(20, 50, 100, 150, 200, 300, 500, 1000)

    override fun initContentView(savedInstanceState: Bundle?): Int {
        return R.layout.activity_electric_pay
    }

    override fun initVariableId(): Int {
        return BR.viewModel
    }

    override fun initViewModel(): ElectricPayViewModel? {
        val lm = ElectricPayRequest()
        return ElectricPayViewModel(getApplication(), lm)
    }


    override fun initData() {
        super.initData()

        //设置电表列表
        viewModel.adapter = ElectricListAdapter(this);

        /*支付传值使用*/
        viewModel.parsePrice.set(0)
        // 清空选中状态
        viewModel.priceAdapter?.select = RecyclerView.NO_POSITION // 或其他表示无效位置的值
        viewModel.adapter.setOnItemClick { position, data ->
            viewModel.adapter.select = position
            viewModel.getElectricInfo(data)
            viewModel.first.set(View.VISIBLE)
            viewModel.adapter.notifyDataSetChanged()

        }
        binding.rvOrderList.adapter = viewModel.adapter

        //设置金额列表
        viewModel.priceAdapter = ElectricPriceAdapter(this)
        viewModel.priceAdapter.mList = prices.toMutableList()

        // 在设置监听器之前确保 viewModel.priceAdapter 不为空
        if (viewModel.priceAdapter != null) {
            viewModel.priceAdapter.setOnItemClick { position, data ->
                if (position != RecyclerView.NO_POSITION) {
                    viewModel.priceAdapter?.select = position
                    viewModel.parsePrice.set(data)
                    viewModel.price.set(data.toString())
                    // 清空选中状态
                    viewModel.priceAdapter?.select = RecyclerView.NO_POSITION // 或其他表示无效位置的值
                    viewModel.priceAdapter?.notifyDataSetChanged()

                }
            }
        }
        binding.rvAepPrice.adapter = viewModel.priceAdapter

        /*支付金额*/
        binding.etAepPrice.addTextChangedListener(object : TextWatcher {

            override fun beforeTextChanged(p0: CharSequence?, p1: Int, p2: Int, p3: Int) {

            }

            override fun onTextChanged(p0: CharSequence?, p1: Int, p2: Int, p3: Int) {
                /*只有有值就开启支付按钮*/
                if (p0.isNullOrBlank()) {
                    // 当 p0 为空或者只包含空白字符时，隐藏 statusCompletedId
                    binding.statusCompletedId.visibility = View.GONE
                    binding.statusNoCompletedId.visibility = View.VISIBLE
                } else {
                    // 当 p0 有值时，显示 statusCompletedId
                    binding.statusCompletedId.visibility = View.VISIBLE
                    binding.statusNoCompletedId.visibility = View.GONE
                }

                /*回显使用*/
                viewModel.price.set(p0.toString() ?: "")
                /*支付弹窗金额回显*/
                if (p0.toString().length > 0) {
                    StaticData.parsePrice = p0.toString().toInt()
                }
                /*支付传值使用*/
                viewModel.parsePrice.set(p0.toString().toIntOrNull() ?: 0)

            }

            override fun afterTextChanged(p0: Editable?) {

            }
        })
        // 如果图片有刷新就会进行更新
        viewModel.storeImageUrl.observe(this) { imageUrl ->
            if (imageUrl != null) {
                Glide.with(this).load(imageUrl).transform(
                    RoundedCorners(40)
                ).into(binding.imageStore)
            }
        }


        viewModel.call.observe(this) { call ->
            if (!TextUtils.isEmpty(call)) {
                rp.request(Manifest.permission.CALL_PHONE, Manifest.permission.READ_EXTERNAL_STORAGE).subscribe(object: Observer<Boolean>{
                    override fun onSubscribe(d: Disposable) {

                    }

                    override fun onError(e: Throwable) {
                        ToastUtils.showShort("请开启拨打电话权限，否则无法正常使用完整功能")
                    }

                    override fun onComplete() {

                    }

                    override fun onNext(t: Boolean) {
                        if (t) {
                            val intent = Intent(Intent.ACTION_CALL)
                            val data = Uri.parse("tel:13011367877")
                            intent.data = data
                            startActivity(intent)
                        } else {
                            ToastUtils.showShort("请开启拨打电话权限，否则无法正常使用完整功能")
                        }
                    }

                })

            }
        }
    }
}
