package com.xx.merchanthbh.ui.electric;

import static android.provider.ContactsContract.Directory.PACKAGE_NAME;

import android.app.Application;
import android.content.Context;
import android.content.Intent;
import android.content.pm.PackageInfo;
import android.content.pm.PackageManager;
import android.net.Uri;
import android.util.Log;
import android.view.View;

import androidx.annotation.NonNull;
import androidx.databinding.ObservableField;
import androidx.lifecycle.LiveData;
import androidx.lifecycle.MutableLiveData;

import com.chinaums.pppay.unify.UnifyPayPlugin;
import com.chinaums.pppay.unify.UnifyPayRequest;
import com.unionpay.UPPayAssistEx;
import com.xx.merchanthbh.data.http.requst.ElectricPayRequest;
import com.xx.merchanthbh.data.http.respons.AdvertisingBean;
import com.xx.merchanthbh.data.http.respons.ElectricInfoBean;
import com.xx.merchanthbh.data.http.respons.ElectricMsgBean;
import com.xx.merchanthbh.data.http.respons.EletricListBean;
import com.xx.merchanthbh.data.http.respons.MerchantBean;
import com.xx.merchanthbh.data.http.respons.PayMsgBean;
import com.xx.merchanthbh.data.http.respons.UserBean;
import com.xx.merchanthbh.data.http.respons.UserInfoBean;
import com.xx.merchanthbh.data.local.LocalData;
import com.xx.merchanthbh.data.staticdata.StaticData;
import com.xx.merchanthbh.dialog.data.TextListProvider;
import com.xx.merchanthbh.ui.appeal.AppealActivity;
import com.xx.merchanthbh.ui.bill.BillListActivity;
import com.xx.merchanthbh.ui.consult.ConsultationViewModel;
import com.xx.xxviewlibrary.base.AppManager;
import com.xx.xxviewlibrary.base.xxBaseDialog;
import com.xx.xxviewlibrary.comm.CommTextDialog;
import com.xx.xxviewlibrary.comm.RefuseDialogBean;

import org.json.JSONException;

import java.util.List;

import io.reactivex.rxjava3.disposables.Disposable;
import io.reactivex.rxjava3.functions.Consumer;
import me.goldze.mvvmhabit.base.BaseViewModel;
import me.goldze.mvvmhabit.http.ApiDisposableObserver;
import me.goldze.mvvmhabit.utils.RxUtils;
import me.goldze.mvvmhabit.utils.ToastUtils;

public class ElectricPayViewModel extends BaseViewModel<ElectricPayRequest> {
    //   创建商户logo的实体对象
    private MutableLiveData<String> storeImageUrl = new MutableLiveData<>("");


    public  MutableLiveData<String> call = new MutableLiveData<>("");

    //商户信息
    public MerchantBean userMerchant = LocalData.getMerchant();

    //公司名称
    public ObservableField<String> companyName = new ObservableField<>("");

    public ObservableField<ElectricMsgBean> electricMsg = new ObservableField<>();

    //电表详情
    public ObservableField<ElectricInfoBean> electricInfo = new ObservableField<>();

    //初始化隐藏
    public ObservableField<Integer> first = new ObservableField<>(View.GONE);
    //充值金额(做前端回显使用)
    public ObservableField<String> price = new ObservableField<>("");
    //充值金额(做接口传值使用)
    public ObservableField<Integer> parsePrice = new ObservableField<>(parseIntegerOrDefault(price.get()));

    // 辅助方法，将字符串解析为整数，如果字符串为空则返回默认值
    private int parseIntegerOrDefault(String value) {
        if (value != null && !value.isEmpty()) {
            try {
                return Integer.parseInt(value);
            } catch (NumberFormatException e) {
                // 处理转换异常
            }
        }
        return 0; // 默认值
    }

    public ElectricListAdapter adapter;

    public ElectricPriceAdapter priceAdapter;

    /*商户图片回显*/
    public LiveData<String> getStoreImageUrl() {
        return storeImageUrl;
    }

    public ElectricPayViewModel(@NonNull Application application) {
        super(application);
    }

    public ElectricPayViewModel(@NonNull Application application, ElectricPayRequest model) {
        super(application, model);
    }

    @Override
    public void onResume() {
        super.onResume();
        getElectricMsg();
        if (adapter.getSelect() >= 0) {
            getElectricInfo(adapter.mList.get(adapter.getSelect()));
        }
    }

    /**
     * 获取电表信息
     */
    public void getElectricMsg() {
        model.getElectricMsg().compose(RxUtils.schedulersTransformer()) //线程调度
                .doOnSubscribe(ElectricPayViewModel.this)
                .doOnSubscribe(new Consumer<Disposable>() {
                    @Override
                    public void accept(Disposable disposable) throws Exception {
                    }
                }).subscribe(new ApiDisposableObserver<ElectricMsgBean>() {

                    @Override
                    public void onSuccess(ElectricMsgBean resultBean) {
                        /*赋值公司图片*/
                        storeImageUrl.setValue(resultBean.getCompanyImage());
                        //赋值公司名称
                        companyName.set(resultBean.getCompanyName());
                        electricMsg.set(resultBean);
                        if (resultBean.getItemList().size() >= 1) {
                            adapter.mList = resultBean.getItemList();
                            adapter.notifyDataSetChanged();

                            //放入电表列表数据
                            StaticData.ElectricList.clear();
                            StaticData.ElectricList.add(new EletricListBean(0, null, -1, "全部", "", null, null));
                            StaticData.ElectricList.addAll(resultBean.getItemList());
                        }


                    }

                    @Override
                    public void onError(String Error) {

                    }
                });
    }


    /**
     * 获取电表信息
     */
    public void getElectricInfo(EletricListBean bean) {
        model.getElectricInfo(bean.getAccountId(), bean.getItemId(), bean.getItemType()).compose(RxUtils.schedulersTransformer()) //线程调度
                .doOnSubscribe(ElectricPayViewModel.this)
                .doOnSubscribe(new Consumer<Disposable>() {
                    @Override
                    public void accept(Disposable disposable) throws Exception {
                    }
                }).subscribe(new ApiDisposableObserver<ElectricInfoBean>() {

                    @Override
                    public void onSuccess(ElectricInfoBean resultBean) {
                        electricInfo.set(resultBean);

                    }

                    @Override
                    public void onError(String Error) {

                    }
                });
    }


    public void requestPayMsg(Context context, PayWayData data) {
        model.requestPayMsg(electricInfo.get(), userMerchant.getBusinessId(), parsePrice.get(), data.getWay()).compose(RxUtils.schedulersTransformer()) //线程调度
                .doOnSubscribe(ElectricPayViewModel.this)
                .doOnSubscribe(new Consumer<Disposable>() {
                    @Override
                    public void accept(Disposable disposable) throws Exception {
                    }
                }).subscribe(new ApiDisposableObserver<PayMsgBean>() {

                    @Override
                    public void onSuccess(PayMsgBean resultBean) {
                        Log.v("价格", price.get().toString());
                        if (data.getWay().equals("UNION_PAY")) {

                            //云闪付
                            String tn = "空";
                            tn = resultBean.getAppPayRequest().get("tn").getAsString();
                            UPPayAssistEx.startPay(context, null, null, tn, "00");
                        } else {
                            //微信和支付宝
                            UnifyPayRequest msg = new UnifyPayRequest();
                            msg.payChannel = data.getChannel();
                            msg.payData = resultBean.getAppPayRequest().toString();
                            UnifyPayPlugin.getInstance(context).sendPayRequest(msg);
                        }

                        if (!data.getWay().equals("WECHAT")) {
                            showCommTextDialog(new RefuseDialogBean("是否完成支付", "完成支付", "未完成支付"), new CommTextDialog.onAcceptCallBack() {
                                @Override
                                public void acceptBack() {
                                    startActivity(BillListActivity.class);
                                }

                                @Override
                                public void refuseBack() {
                                }
                            });
                        }

                    }

                    @Override
                    public void onError(String Error) {

                    }
                });
    }

    /**
     * 支付
     *
     * @param view
     */
    public void pay(View view) {
        PayWayDialog dialog = new PayWayDialog(AppManager.getAppManager().currentActivity());
        dialog.setDialogClickListener(new xxBaseDialog.onDialogClickListener<PayWayData>() {
            @Override
            public void dialogClickBack(int code, PayWayData data) {
                String p = "";
                String name = "微信";
                if (data.getWay().equals("UNION_PAY")) {
                    p = "com.unionpay";
                    name = "云闪付";
                } else if (data.getWay().equals("ALIPAY")) {
                    p = "com.eg.android.AlipayGphone";
                    name = "支付宝";
                } else {
                    p = "com.tencent.mm";
                }
                PackageManager pm = view.getContext().getPackageManager();
                try {
                    PackageInfo info = pm.getPackageInfo(p, 0);
                    if (info == null) {
                        ToastUtils.showShort("未安装<" + name + ">app");
                        return;

                    }
                } catch (PackageManager.NameNotFoundException e) {
                    e.printStackTrace();
                    ToastUtils.showShort("未安装<" + name + ">app");
                    return;
                }

                requestPayMsg(view.getContext(), data);
            }
        });

        dialog.show();

    }

    public void callPhone(View view)
    {
        showCommTextDialog(new RefuseDialogBean("客服电话：13011367877", "呼叫", "取消", ""), new CommTextDialog.onAcceptCallBack() {
            @Override
            public void acceptBack() {


             call.postValue("1231");
            }

            @Override
            public void refuseBack() {
                dismissDialog();
            }
        });
    }



    public View.OnClickListener goBillList = new View.OnClickListener() {
        @Override
        public void onClick(View view) {
            startActivity(BillListActivity.class);
        }
    };


}
