package com.xx.merchanthbh.ui.login

import android.content.Context
import android.content.Intent
import android.net.Uri
import android.os.Build
import android.os.Bundle
import android.os.Environment
import android.provider.Settings
import android.text.SpannableStringBuilder
import android.text.Spanned
import android.text.TextPaint
import android.text.method.LinkMovementMethod
import android.text.style.ClickableSpan
import android.util.Log
import android.view.View
import androidx.core.content.edit
import androidx.lifecycle.Observer
import com.tbruyelle.rxpermissions3.RxPermissions
import com.xx.merchanthbh.BR
import com.xx.merchanthbh.R
import com.xx.merchanthbh.data.http.requst.LoginRequest
import com.xx.merchanthbh.data.staticdata.StaticData
import com.xx.merchanthbh.databinding.ActivityLoginBinding
import com.xx.merchanthbh.ui.web.CommWabActivity
import com.xx.merchanthbh.utils.RetrofitClient
import com.xx.xxviewlibrary.comm.CommTextAgreeDialog
import com.xx.xxviewlibrary.comm.CommTextDialog.onAcceptCallBack
import com.xx.xxviewlibrary.comm.RefuseDialogBean
import me.goldze.mvvmhabit.base.BaseActivity
import me.goldze.mvvmhabit.utils.SPUtils
import me.goldze.mvvmhabit.utils.ToastUtils


class LoginActivity() : BaseActivity<ActivityLoginBinding, LoginViewModel>() {


    override fun initContentView(savedInstanceState: Bundle?): Int {

        return R.layout.activity_login

    }

    override fun initVariableId(): Int {
        return BR.loginViewModel
    }

    override fun onResume() {
        super.onResume()
//        注销标志位重置
        StaticData.logOffData = 0
    }

    var agreementContext: String = ""
    override fun initData() {

        //检查版本
        viewModel.rxPermissions = RxPermissions(this)
        // 获得协议内容
        viewModel.getProtocols()
        SPUtils.getInstance().clear()
        super.initData()
        /*强制更新标识位变更--重置用户登录*/
        StaticData.updateLogin = 1

        // 使用SharedPreferences检查是否是第一次打开应用
        val preferences = getPreferences(Context.MODE_PRIVATE)
        val isAgreeFlag = preferences.getBoolean("is_agree_flag", true)
        if (isAgreeFlag) {
            // 如果是第一次打开应用，执行相应的操作
            viewModel.agreeContent.observe(this) { agreeContent: String? ->
                if (agreeContent != null) {
                    agreementContext = agreeContent
//                    在这里加上隐私协议弹窗
                    showCommTextAgreeDialog(
                        RefuseDialogBean(agreementContext, "同意", "不同意", "隐私条款"),
                        object : onAcceptCallBack, CommTextAgreeDialog.onAcceptCallBack {
                            override fun refuseBack() {
                                finish()
                                val intent = Intent(Intent.ACTION_MAIN)
                                intent.addCategory(Intent.CATEGORY_HOME)
                                intent.flags = Intent.FLAG_ACTIVITY_NEW_TASK
                                startActivity(intent)
                            }

                            override fun acceptBack() {
                                // 设置is_agree_flag标记为false，表示隐私协议已同意
                                val editor = preferences.edit()
                                editor.putBoolean("is_agree_flag", false)
                                editor.apply()
//                                检查版本
                                viewModel.checkVersion(binding.root.rootView)
                            }
                        })
                }
            }


        } else {
            viewModel.checkVersion(binding.root.rootView)
        }

        //安装新版本
        viewModel.openInstall.observe(this, Observer<String?> {
            fun onChanged(s: String) {
                if ("1" == s) {
                    val packageURI = Uri.parse("package:" + applicationContext.packageName)
                    val intent = Intent(Settings.ACTION_MANAGE_UNKNOWN_APP_SOURCES, packageURI)
                    startActivityForResult(intent, 1002)
                }
            }
        })
       /* if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.R) {

            if (!Environment.isExternalStorageManager()) {
                val intent = Intent(Settings.ACTION_MANAGE_APP_ALL_FILES_ACCESS_PERMISSION)
                intent.setData(Uri.parse("package:$packageName"))
                startActivityForResult(intent, 1024)
            }
        }*/
        if (viewModel.isAgree)
        {
            binding.ivLoginAgreement.setImageDrawable(getDrawable(R.mipmap.login_icon_xuanze2))
        } else {
            binding.ivLoginAgreement.setImageDrawable(getDrawable(R.mipmap.login_icon_xuanze1))
        }


        binding.ivLoginAgreement.setOnClickListener()
        {
            if (viewModel.isAgree) {
                viewModel.isAgree = false
                binding.ivLoginAgreement.setImageDrawable(getDrawable(R.mipmap.login_icon_xuanze1))
            } else {
                viewModel.isAgree = true
                binding.ivLoginAgreement.setImageDrawable(getDrawable(R.mipmap.login_icon_xuanze2))
            }
        }


        var sp: SpannableStringBuilder =
            SpannableStringBuilder("我已阅读并同意《用户协议》、《隐私条款》")
//        sp.setSpan(ForegroundColorSpan(getColor(R.color.text_grey_blue)),7,20,Spanned.SPAN_EXCLUSIVE_EXCLUSIVE)
        binding.tvLoginAgree.setMovementMethod(LinkMovementMethod.getInstance());
        binding.tvLoginAgree.setHighlightColor(0)

        sp.setSpan(object : ClickableSpan() {
            override fun onClick(view: View) {


                if (StaticData.Protocols.size >= 5) {
                    var bundle: Bundle = Bundle();
                    bundle.putString("title", "用户协议")
                    bundle.putString("URL", RetrofitClient.baseH5Url + StaticData.Protocols.get(4))
                    startActivity(CommWabActivity::class.java, bundle)
                }

            }

            override fun updateDrawState(ds: TextPaint) {
                ds.setColor(getColor(R.color.text_grey_blue))
                ds.isUnderlineText = false

            }
        }, 7, 13, Spanned.SPAN_EXCLUSIVE_EXCLUSIVE)

        sp.setSpan(object : ClickableSpan() {
            override fun onClick(view: View) {

                if (StaticData.Protocols.size >= 3) {
                    var bundle: Bundle = Bundle();
                    bundle.putString("title", "隐私条款")
                    bundle.putString("URL", RetrofitClient.baseH5Url + StaticData.Protocols.get(2))
                    startActivity(CommWabActivity::class.java, bundle)
                }
            }

            override fun updateDrawState(ds: TextPaint) {
                ds.setColor(getColor(R.color.text_grey_blue))
                ds.isUnderlineText = false

            }
        }, 14, 20, Spanned.SPAN_EXCLUSIVE_EXCLUSIVE)

        binding.tvLoginAgree.text = sp

    }

    override fun initViewObservable() {
        super.initViewObservable()
    }

    override fun initViewModel(): LoginViewModel {
        val lm: LoginRequest = LoginRequest()
        return LoginViewModel(application, lm)
    }

}