package com.xx.merchanthbh.ui.login;

import static me.goldze.mvvmhabit.utils.Utils.Interceptor_TOKEN;
import static me.goldze.mvvmhabit.utils.Utils.getContext;

import android.Manifest;
import android.app.Application;
import android.content.Context;
import android.content.Intent;
import android.net.Uri;
import android.os.Build;
import android.os.Bundle;
import android.text.Html;
import android.text.TextUtils;
import android.util.Log;
import android.view.View;
import android.widget.Toast;

import androidx.annotation.NonNull;
import androidx.core.content.FileProvider;
import androidx.databinding.ObservableField;
import androidx.lifecycle.MutableLiveData;
import androidx.lifecycle.ViewModel;

import com.tbruyelle.rxpermissions3.RxPermissions;
import com.xx.merchanthbh.R;
import com.xx.merchanthbh.data.http.requst.LoginRequest;
import com.xx.merchanthbh.data.http.respons.UserInfoBean;
import com.xx.merchanthbh.data.local.LocalData;
import com.xx.merchanthbh.data.staticdata.StaticData;
import com.xx.merchanthbh.ui.home.HomeActivity;
import com.xx.merchanthbh.ui.merchantenter.MerchantEnterActivity;
import com.xx.merchanthbh.ui.mine.MineViewModel;
import com.xx.merchanthbh.ui.pwd.ForgetPwdActivity;
import com.xx.merchanthbh.ui.pwd.PwdActivity;
import com.xx.merchanthbh.ui.pwd.SetPwdActivity;
import com.xx.merchanthbh.ui.web.CommWabActivity;
import com.xx.merchanthbh.utils.RetrofitClient;
import com.xx.xxviewlibrary.comm.CommTextDialog;
import com.xx.xxviewlibrary.comm.RefuseDialogBean;
import com.xx.xxviewlibrary.model.VersionBean;
import com.xx.xxviewlibrary.utils.CommUtilsKt;

import java.io.File;
import java.util.List;

import io.reactivex.rxjava3.core.Observer;
import io.reactivex.rxjava3.disposables.CompositeDisposable;
import io.reactivex.rxjava3.disposables.Disposable;
import io.reactivex.rxjava3.functions.Consumer;
import io.reactivex.rxjava3.schedulers.Schedulers;
import me.goldze.mvvmhabit.base.BaseViewModel;
import me.goldze.mvvmhabit.binding.command.BindingAction;
import me.goldze.mvvmhabit.binding.command.BindingCommand;
import me.goldze.mvvmhabit.http.ApiDisposableObserver;
import me.goldze.mvvmhabit.utils.RxUtils;
import me.goldze.mvvmhabit.utils.ToastUtils;
import okhttp3.ResponseBody;

public class LoginViewModel extends BaseViewModel<LoginRequest> {

    /*权限*/
    RxPermissions rxPermissions;
    //用户名的绑定
    public ObservableField<String> userName = new ObservableField<>("");
    /*隐私条款字段*/
    public MutableLiveData<String> agreeContent = new MutableLiveData<>(null);
    //密码的绑定
    public ObservableField<String> password = new ObservableField<>("");
    /*安装新版本*/
    public MutableLiveData<String> openInstall = new MutableLiveData<>("");
    public boolean isAgree = false;

    public LoginViewModel(@NonNull Application application, LoginRequest model) {
        super(application, model);
    }

    /**
     * 获取最新APK版本号
     *
     * @param view
     */
    public void checkVersion(View view) {
        Log.v("版本更新", "版本更新");
        model.checkVersion().compose(RxUtils.schedulersTransformer()) //线程调度
                .doOnSubscribe(LoginViewModel.this)
                .doOnSubscribe(new Consumer<Disposable>() {
                    @Override
                    public void accept(Disposable disposable) throws Exception {
                    }
                }).subscribe(new ApiDisposableObserver<VersionBean>() {

                    @Override
                    public void onSuccess(VersionBean resultBean) {
                        /*强制更新标识位变更--重置用户登录*/
                        StaticData.updateLogin = 1;
                        Log.v("当前版本号", resultBean.getAppVersion());
                        StaticData.appVersionNumber = resultBean.getAppVersion();
                        if (CommUtilsKt.checkVersionUpdata(CommUtilsKt.getVersion(view.getContext()), resultBean.getAppVersion())) {
                            if (resultBean.getPushFlag().equals("1")) {
                                showCommTextDialog(new RefuseDialogBean("有新版本,是否更新?", "去更新", null, "更新提示"), new CommTextDialog.onAcceptCallBack() {
                                    @Override
                                    public void refuseBack() {
                                        finish();
                                    }

                                    @Override
                                    public void acceptBack() {
                                        /*强制更新标识位变更--禁止用户登录*/
                                        StaticData.updateLogin = 0;
                                        rxPermissions
                                                .request(Manifest.permission.WRITE_EXTERNAL_STORAGE)
                                                .subscribe(granted -> {
                                                    if (granted) {
                                                        // 处理权限已授予的情况
                                                        updataApk(view.getContext(), resultBean.getVersionFile(), view.getContext().getFilesDir().getPath() + resultBean.getVersionFile().substring(
                                                                resultBean.getVersionFile().lastIndexOf("/")));
                                                    } else {
                                                        // 处理权限被拒绝的情况
                                                        ToastUtils.showShort("请开启文件相关权限");
                                                    }
                                                });

                                    }
                                });
                            } else {
                                showCommTextDialog(new RefuseDialogBean("有新版本,是否更新?", "去更新", "取消", "更新提示"), new CommTextDialog.onAcceptCallBack() {
                                    @Override
                                    public void refuseBack() {
                                        /*强制更新标识位变更--重置用户登录*/
                                        StaticData.updateLogin = 1;
                                    }

                                    @Override
                                    public void acceptBack() {
                                        /*强制更新标识位变更--可以用户登录*/
                                        StaticData.updateLogin = 0;
                                        rxPermissions
                                                .request(Manifest.permission.WRITE_EXTERNAL_STORAGE)
                                                .unsubscribeOn(Schedulers.io()) // 使订阅不可取消
                                                .subscribe(granted -> {
                                                    if (granted) {
                                                        updataApk(view.getContext(), resultBean.getVersionFile(), view.getContext().getFilesDir().getPath() + resultBean.getVersionFile().substring(
                                                                resultBean.getVersionFile().lastIndexOf("/")));
                                                    } else {
                                                        ToastUtils.showShort("请开启文件相关权限");
                                                    }
                                                });
                                    }
                                });
                            }

                        } else {
                            /*强制更新标识位变更--重置用户登录*/
                            StaticData.updateLogin = 1;
                        }


                    }

                    @Override
                    public void onError(String Error) {

                        /*强制更新标识位变更--重置用户登录*/
                        StaticData.updateLogin = 1;
                    }
                });
    }

    /**
     * 下载APK
     *
     * @param context
     * @param url     　下载地址
     * @param name    　文件名字
     */
    public void updataApk(Context context, String url, String name) {
        /*执行传参方法*/
        showDialog("正在下载...");

        model.downFile(url, name).subscribe(new Observer<ResponseBody>() {
            @Override
            public void onSubscribe(@io.reactivex.rxjava3.annotations.NonNull Disposable d) {
                Log.e("下载", "onSubscribe");

            }

            @Override
            public void onNext(@io.reactivex.rxjava3.annotations.NonNull ResponseBody responseBody) {

            }

            @Override
            public void onError(@io.reactivex.rxjava3.annotations.NonNull Throwable e) {
                ToastUtils.showShort("下载失败");
                dismissDialog();
            }

            @Override
            public void onComplete() {
                Log.e("下载要成功", "onComplete");
                dismissDialog();
                ToastUtils.showShort("下载成功");
                installApk(context, name);
            }
        });
    }

    //跳转安装ＡＰＰ
    private void installApk(Context context, String path) {
        Intent intent = new Intent(Intent.ACTION_VIEW);
        intent.addFlags(Intent.FLAG_ACTIVITY_NEW_TASK);
        File file = new File(Uri.parse(path).getPath());
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.N) {
            intent.addFlags(Intent.FLAG_GRANT_READ_URI_PERMISSION);
            Uri uri = FileProvider.getUriForFile(context, "com.xx.merchanthbh.fileProvider", file);
            intent.setDataAndType(uri, "application/vnd.android.package-archive");
        } else {
            intent.setDataAndType(Uri.fromFile(file), "application/vnd.android.package-archive");
        }
        context.startActivity(intent);

    }


    //跳转开店页面
    public BindingCommand goMerchantEnter = new BindingCommand(new BindingAction() {
        @Override
        public void call() {
            Bundle bundle = new Bundle();
            bundle.putInt("pageStep", R.id.merchantIntroduceFragment);
            startActivity(MerchantEnterActivity.class, bundle);
        }
    });

    //跳转首页
    public BindingCommand goHome = new BindingCommand(new BindingAction() {
        @Override
        public void call() {
            startActivity(HomeActivity.class);
        }

    });

    //跳转忘记密码
    public BindingCommand forgetPwd = new BindingCommand(new BindingAction() {
        @Override
        public void call() {
            startActivity(ForgetPwdActivity.class);
        }

    });
    //登陆
    public BindingCommand login = new BindingCommand(new BindingAction() {
        @Override
        public void call() {
            if (StaticData.updateLogin == 0) {
                Toast.makeText(getContext(), "请安装最新版本!", Toast.LENGTH_SHORT).show();

                model.checkVersion().compose(RxUtils.schedulersTransformer()) //线程调度
                        .doOnSubscribe(LoginViewModel.this)
                        .doOnSubscribe(new Consumer<Disposable>() {
                            @Override
                            public void accept(Disposable disposable) throws Exception {
                            }
                        }).subscribe(new ApiDisposableObserver<VersionBean>() {

                            @Override
                            public void onSuccess(VersionBean resultBean) {
                                if (CommUtilsKt.checkVersionUpdata(CommUtilsKt.getVersion(getApplication().getApplicationContext()), resultBean.getAppVersion())) {


                                    //不强制
                                    if (resultBean.getPushFlag().equals("0")) {
                                        showCommTextDialog(new RefuseDialogBean("有新版本,是否更新?", "去更新", "取消", "更新提示"), new CommTextDialog.onAcceptCallBack() {
                                            @Override
                                            public void refuseBack() {

                                                /*强制更新标识位变更--重置用户登录*/
                                                StaticData.updateLogin = 1;
                                            }

                                            @Override
                                            public void acceptBack() {
                                                rxPermissions
                                                        .request(Manifest.permission.WRITE_EXTERNAL_STORAGE)
                                                        .subscribe(granted -> {
                                                            if (granted) {
                                                                updataApk(getApplication().getApplicationContext(), resultBean.getVersionFile(), getApplication().getApplicationContext().getFilesDir().getPath() + resultBean.getVersionFile().substring(
                                                                        resultBean.getVersionFile().lastIndexOf("/")));

                                                            } else {
                                                                ToastUtils.showShort("请开启文件相关权限");
                                                            }
                                                        });

                                            }
                                        });
                                    } else {
                                        showCommTextDialog(new RefuseDialogBean("有新版本,是否更新?", "去更新", null, "更新提示"), new CommTextDialog.onAcceptCallBack() {
                                            @Override
                                            public void refuseBack() {
                                                finish();

                                                /*强制更新标识位变更--重置用户登录*/
                                                StaticData.updateLogin = 1;
                                            }

                                            @Override
                                            public void acceptBack() {

                                                rxPermissions
                                                        .request(Manifest.permission.WRITE_EXTERNAL_STORAGE)
                                                        .subscribe(granted -> {
                                                            if (granted) {
                                                                updataApk(getApplication().getApplicationContext(), resultBean.getVersionFile(), getApplication().getApplicationContext().getFilesDir().getPath() + resultBean.getVersionFile().substring(
                                                                        resultBean.getVersionFile().lastIndexOf("/")));
                                                            } else {
                                                                ToastUtils.showShort("请开启文件相关权限");
                                                            }
                                                        });

                                            }
                                        });
                                    }

                                } else {
                                    /*强制更新标识位变更--重置用户登录*/
                                    StaticData.updateLogin = 1;
                                }


                            }

                            @Override
                            public void onError(String Error) {

                            }
                        });
            } else {

                if (!isAgree) {
                    ToastUtils.showShort("请阅读并同意协议");
                    return;

                }
                if (TextUtils.isEmpty(userName.get().toString())) {
                    ToastUtils.showShort("请输入账号！");

                } else if (TextUtils.isEmpty(password.get().toString())) {
                    ToastUtils.showShort("请输入密码！");
                } else {
                    model.Login(userName.get().toString(), password.get().toString())
                            .compose(RxUtils.schedulersTransformer()) //线程调度
//                        .compose(RxUtils.exceptionTransformer()) // 网络错误的异常转换, 这里可以换成自己的ExceptionHandle
                            .doOnSubscribe(LoginViewModel.this)
                            .doOnSubscribe(new Consumer<Disposable>() {
                                @Override
                                public void accept(Disposable disposable) throws Exception {
                                    showDialog("正在请求...");
                                }
                            }).subscribe(new ApiDisposableObserver<String>() {
                                @Override
                                public void onSuccess(String resultBean) {
                                    //是指token
                                    Interceptor_TOKEN = "Bearer " + resultBean;
                                    getuserInfo();
//                                startActivity(HomeActivity.class);
                                }

                                @Override
                                public void onError(String Error) {
                                    dismissDialog();
                                }

                            });
                }


            }
        }
    });


    /**
     * 获取用户信息
     */
    public void getuserInfo() {


        model.getUserInfo()
                .compose(RxUtils.schedulersTransformer()) //线程调度
//                        .compose(RxUtils.exceptionTransformer()) // 网络错误的异常转换, 这里可以换成自己的ExceptionHandle
                .doOnSubscribe(LoginViewModel.this)
                .doOnSubscribe(new Consumer<Disposable>() {
                    @Override
                    public void accept(Disposable disposable) throws Exception {
                    }
                }).subscribe(new ApiDisposableObserver<UserInfoBean>() {
                    @Override
                    public void onSuccess(UserInfoBean resultBean) {
                        Log.v("昵称昵称啊", resultBean.getUser().getNickName());
                        //将用户信息存储到本地
                        LocalData.saveUser(resultBean.getUser());
                        /*在登录的时候就给staticData的消息标志位设置成未读*/
                        StaticData.flag = 0;
                        dismissDialog();
                        if (resultBean.getMerchant() == null) {
                            Bundle bundle = new Bundle();
                            bundle.putInt("pageStep", R.id.registerMaterialFragment);
                            startActivity(MerchantEnterActivity.class, bundle);
                        } else if (resultBean.getMerchant().getAuditStatus().equals("0")) {
                            Bundle bundle = new Bundle();
                            bundle.putInt("pageStep", R.id.merchantWaitFragment);
                            startActivity(MerchantEnterActivity.class, bundle);
                        } else if (resultBean.getMerchant().getAuditStatus().equals("2")) {
                            LocalData.saveMerchant(resultBean.getMerchant());
                            Bundle bundle = new Bundle();
                            bundle.putInt("pageStep", R.id.registerMaterialFragment);
                            startActivity(MerchantEnterActivity.class, bundle);
                        } else if (resultBean.getNeedChangeInitPassword()) {
                            startActivity(SetPwdActivity.class);
                        } else if (resultBean.getNeedChangeTimeLongPassword()) {
                            /*执行超期弹窗方法*/
                            ShowOverDueDialog();
                        } else {
                            LocalData.saveMerchant(resultBean.getMerchant());
//                        判断是否是店长
                            if (resultBean.getUser().getUserId() == resultBean.getMerchant().getUserId()) {
                                StaticData.personType = 0;
                            } else {
                                StaticData.personType = 1;
                            }
                            LocalData.saveMerchant(resultBean.getMerchant());
                            startActivity(HomeActivity.class);
                        }

//                        finish();
                    }

                    @Override
                    public void onError(String Error) {
                        dismissDialog();
                    }


                });
    }

    /**
     * 密码超期显示
     */
    public void ShowOverDueDialog() {
        showCommTextDialog(new RefuseDialogBean("您的密码使用时间过长,请修改密码后重新登录", "修改密码", "取消", "温馨提示"), new CommTextDialog.onAcceptCallBack() {
            @Override
            public void refuseBack() {
                /*跳转到首页(首先获取用户信息)*/
                model.getUserInfo()
                        .compose(RxUtils.schedulersTransformer()) //线程调度
//                        .compose(RxUtils.exceptionTransformer()) // 网络错误的异常转换, 这里可以换成自己的ExceptionHandle
                        .doOnSubscribe(LoginViewModel.this)
                        .doOnSubscribe(new Consumer<Disposable>() {
                            @Override
                            public void accept(Disposable disposable) throws Exception {
                            }
                        }).subscribe(new ApiDisposableObserver<UserInfoBean>() {
                            @Override
                            public void onSuccess(UserInfoBean resultBean) {

                                //将用户信息存储到本地
                                LocalData.saveUser(resultBean.getUser());
                                /*在登录的时候就给staticData的消息标志位设置成未读*/
                                StaticData.flag = 0;
                                dismissDialog();
                                LocalData.saveMerchant(resultBean.getMerchant());
                                startActivity(HomeActivity.class);
                            }

                            @Override
                            public void onError(String Error) {
                                dismissDialog();
                            }
                        });
            }


            @Override
            public void acceptBack() {
                /*跳转到修改密码页面*/
                startActivity(PwdActivity.class);
            }
        });

    }

    /**
     * 获取协议内容
     */
    public void getProtocols() {
        model.getProtocols().compose(RxUtils.schedulersTransformer()) //线程调度
//                        .compose(RxUtils.exceptionTransformer()) // 网络错误的异常转换, 这里可以换成自己的ExceptionHandle
                .doOnSubscribe(LoginViewModel.this)
                .doOnSubscribe(new Consumer<Disposable>() {
                    @Override
                    public void accept(Disposable disposable) throws Exception {
                    }
                }).subscribe(new ApiDisposableObserver<List<String>>() {

                    @Override
                    public void onSuccess(List<String> resultBean) {
                        StaticData.Protocols = resultBean;
                        if (StaticData.Protocols.size() >= 3) {
                            Bundle bundle = new Bundle();
                            bundle.putString("title", "隐私条款");
                            bundle.putString("URL", RetrofitClient.baseH5Url + StaticData.Protocols.get(2));
                            CharSequence htmlText = Html.fromHtml(bundle.toString());
                            /*为隐私条款赋值*/
                            agreeContent.setValue(htmlText.toString());
                        }
                    }

                    @Override
                    public void onError(String Error) {

                    }
                });

    }
}


