package com.xx.merchanthbh.ui.logoff;

import android.app.Application;
import android.content.Intent;
import android.util.Log;
import android.view.View;
import android.widget.RadioButton;
import android.widget.RadioGroup;

import androidx.annotation.NonNull;
import androidx.databinding.ObservableField;
import androidx.lifecycle.MutableLiveData;

import com.xx.merchanthbh.data.http.requst.LogOffRequest;
import com.xx.merchanthbh.data.staticdata.StaticData;
import com.xx.merchanthbh.ui.appeal.AppealEditViewModel;
import com.xx.merchanthbh.ui.login.LoginActivity;

import io.reactivex.rxjava3.android.schedulers.AndroidSchedulers;
import io.reactivex.rxjava3.disposables.Disposable;
import io.reactivex.rxjava3.functions.Consumer;
import io.reactivex.rxjava3.schedulers.Schedulers;
import me.goldze.mvvmhabit.base.BaseViewModel;
import me.goldze.mvvmhabit.http.ApiDisposableObserver;
import me.goldze.mvvmhabit.utils.RxUtils;
import me.goldze.mvvmhabit.utils.ToastUtils;

public class LogOffViewModel extends BaseViewModel<LogOffRequest> {
    //注销原因绑定
    public ObservableField<String> reason = new ObservableField<>("");
    /*注销原因存储*/
    public String reasonValue = "1";
    //注销原因备注绑定
    public ObservableField<String> logOffReasonMark = new ObservableField<>("");
    //注销原因备注绑定是否显示标识位
    public ObservableField<Integer> getOff = new ObservableField<>(View.GONE);
    //下一步是否显示标识位
    public ObservableField<Integer> getNext = new ObservableField<>(View.VISIBLE);
    //下一步是否显示标识位
    public ObservableField<Integer> getNextNo = new ObservableField<>(View.GONE);
    // LiveData表示注销状态
    private MutableLiveData<Boolean> logOffStatus = new MutableLiveData<>();

    // 提供给外部观察注销状态的方法
    public MutableLiveData<Boolean> getLogOffStatus() {
        return logOffStatus;
    }

    public LogOffViewModel(@NonNull Application application) {
        super(application);
    }

    public LogOffViewModel(@NonNull Application application, LogOffRequest model) {
        super(application, model);
    }

    /**
     * 按钮组判断注销原因
     */
    public void initReasonListener(RadioGroup radioGroup) {
        // 设置默认选中第一个RadioButton
        RadioButton firstRadioButton = (RadioButton) radioGroup.getChildAt(0);
        if (firstRadioButton != null) {
            firstRadioButton.setChecked(true);
        }
        /*后面再监听其他*/
        radioGroup.setOnCheckedChangeListener(new RadioGroup.OnCheckedChangeListener() {
            @Override
            public void onCheckedChanged(RadioGroup group, int checkedId) {
                RadioButton radioButton = group.findViewById(checkedId);
                if (radioButton != null) {
                    reason.set(radioButton.getText().toString());
                    /**
                     * 注销原因 (1-需要解绑手机，2-安全/隐私顾虑，3-其他 )
                     * 转换!!!!!!!!!!!!!!!!!!!!
                     */
                    reasonValue = reason.get();
                    if (reasonValue.contains("需要解绑手机")) {
                        // 当文本为空时执行的操作
                        getNext.set(View.VISIBLE);
                        getNextNo.set(View.GONE);
                        reasonValue = "1";
                        /*备注清空*/
                        logOffReasonMark.set("");
                        /*隐藏备注*/
                        getOff.set(View.GONE);
                    } else if (reasonValue.contains("安全/隐私顾虑")) {
                        getNext.set(View.VISIBLE);
                        getNextNo.set(View.GONE);
                        reasonValue = "2";
                        /*备注清空*/
                        logOffReasonMark.set("");
                        // 当文本为空时执行的操作
                        /*隐藏备注*/
                        getOff.set(View.GONE);
                    } else {
                        getNext.set(View.GONE);
                        getNextNo.set(View.VISIBLE);
                        reasonValue = "3";
                        // 当文本为空时执行的操作
                        /*显示备注*/
                        getOff.set(View.VISIBLE);
                    }
                }
            }
        });
    }


    /**
     * 调用注销账号接口
     * 依次传入1-注销备注 2-注销原因 (1-需要解绑手机，2-安全/隐私顾虑，3-其他 )
     */
    public void submitLogOffMsg(View view) {
        Log.v("备注:", logOffReasonMark.get());
        /*如果原因不为空则将其赋值给logOffReasonMarkValue*/
        if (reasonValue.equals("3") && !logOffReasonMark.get().isEmpty() || reasonValue.equals("1") || reasonValue.equals("2")) {
            /*执行传参方法*/
            model.logOffUser(logOffReasonMark.get(), reasonValue)
                    .subscribeOn(Schedulers.io())
                    .observeOn(AndroidSchedulers.mainThread())
                    .compose(RxUtils.schedulersTransformer())
                    .doOnSubscribe(LogOffViewModel.this)
                    .doOnSubscribe(new Consumer<Disposable>() {
                        @Override
                        public void accept(Disposable disposable) throws Exception {

                            showDialog("正在注销...");
                        }
                    })
                    .subscribe(new ApiDisposableObserver<Boolean>() {
                        @Override
                        public void onSuccess(Boolean resultBean) {
                            dismissDialog();
                            ToastUtils.showShort("账号已注销!");
//                            注销标志位改变
                            StaticData.logOffData = 1;
                            logOffStatus.setValue(true);
                            finish();
                        }

                        @Override
                        public void onError(String Error) {
                            // 处理错误
                            dismissDialog();
                        }
                    });

        } else {
            ToastUtils.showShort("请输入其他原因!");
        }
    }

}
