package com.xx.merchanthbh.ui.mine;

import static com.xx.merchanthbh.utils.RetrofitClient.baseImgUrl;

import android.content.Intent;
import android.net.Uri;
import android.os.Build;
import android.os.Bundle;
import android.os.Environment;
import android.provider.Settings;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.lifecycle.Lifecycle;
import androidx.lifecycle.LifecycleOwner;
import androidx.lifecycle.Observer;

import com.bumptech.glide.Glide;
import com.bumptech.glide.load.resource.bitmap.RoundedCorners;
import com.bumptech.glide.load.resource.drawable.DrawableTransitionOptions;
import com.bumptech.glide.request.RequestOptions;
import com.tbruyelle.rxpermissions3.RxPermissions;
import com.xx.merchanthbh.BR;
import com.xx.merchanthbh.R;
import com.xx.merchanthbh.data.local.LocalData;
import com.xx.merchanthbh.data.staticdata.StaticData;
import com.xx.merchanthbh.databinding.FragmentMineBinding;
import com.xx.xxviewlibrary.utils.CommUtilsKt;

import me.goldze.mvvmhabit.base.BaseFragment;
import me.goldze.mvvmhabit.utils.StringUtils;

public class MineFragment extends BaseFragment<FragmentMineBinding, MineViewModel> {


    @Override
    public int viewModelType() {
        return 0;
    }

    @Override
    public int initContentView(LayoutInflater inflater, @Nullable ViewGroup container, @Nullable Bundle savedInstanceState) {
        return R.layout.fragment_mine;
    }

    @Override
    public int initVariableId() {
        return BR.mineViewModel;
    }

    //    重写初始方法调用参数
    @Override
    public void initData() {
        /*设置当前版本号*/
        viewModel.versionName.set(StaticData.appVersionNumber);
        viewModel.rxPermissions = new RxPermissions(this);
        viewModel.versionName.set("当前版本v" + CommUtilsKt.getVersion(getContext()));
//        super.initData();
        // 调用ViewModel的方法来刷新昵称

        /*控制台拿到了图片路径了*/
        /*如果图片有刷新就会进行更新*/
        viewModel.getAvatarImageUrl().observe(this, new Observer<String>() {
            @Override
            public void onChanged(String imageUrl) {
                if (!StringUtils.isEmpty(imageUrl)) {
                    // 设置圆角半径
                    int radius = 120;
                    // 创建圆角转换器
                    RoundedCorners roundedCorners = new RoundedCorners(radius);
                    // 创建Glide请求选项
                    RequestOptions requestOptions = RequestOptions.bitmapTransform(roundedCorners);
                    // 使用Glide加载图片并应用圆角转换器
                    Glide.with(MineFragment.this)
                            .load(baseImgUrl + imageUrl)
                            .apply(requestOptions)
                            .transition(DrawableTransitionOptions.withCrossFade())
                            .into(binding.imageAvatarFemale);
                    /*默认隐*/
                    binding.imageAvatarMale.setVisibility(View.GONE);
                } else {
                    /*头像为空的情况下做男女判断*/
                    if (LocalData.getUser().getSex().equals("0")) {
                        /*男显*/
                        binding.imageAvatarMale.setVisibility(View.VISIBLE);
                        /*女隐*/
                        binding.imageAvatarFemale.setVisibility(View.GONE);
                    } else {
                        /*男隐*/
                        binding.imageAvatarMale.setVisibility(View.GONE);
                        /*女显*/
                        binding.imageAvatarFemale.setVisibility(View.VISIBLE);
                    }
                }
            }
        });


        viewModel.openInstall.observe(this, new Observer<String>() {
            @Override
            public void onChanged(String s) {
                if ("1".equals(s)) {
                  /*  var packageURI = Uri.parse("package:" + getContext().getPackageName());
                    Intent intent = new Intent(Settings.ACTION_MANAGE_UNKNOWN_APP_SOURCES, packageURI);
                    startActivityForResult(intent, 1002);*/
                }

            }
        });
    }

    @Override
    public void onResume() {
        super.onResume();
        viewModel.refreshNickName();

        // 检查版本
        viewModel.rxPermissions = new RxPermissions(this);
        /*检查版本*/
//        viewModel.checkVersion(binding.getRoot().getRootView());

// 安装新版本
        viewModel.openInstall.observe(this, new Observer<String>() {
            @Override
            public void onChanged(String s) {
                if ("1".equals(s)) {
                    Uri packageURI = Uri.parse("package:" +getContext().getPackageName());
                    Intent intent = new Intent(Settings.ACTION_MANAGE_UNKNOWN_APP_SOURCES, packageURI);
                    startActivityForResult(intent, 1002);
                }
            }
        });

        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.R) {
            if (!Environment.isExternalStorageManager()) {
                Intent intent = new Intent(Settings.ACTION_MANAGE_APP_ALL_FILES_ACCESS_PERMISSION);
                intent.setData(Uri.parse("package:" + getContext().getPackageName()));
                startActivityForResult(intent, 1024);
            }
        }
    }
}