package com.xx.merchanthbh.ui.mine;

import android.Manifest;
import android.app.Application;
import android.content.Context;
import android.content.Intent;
import android.net.Uri;
import android.os.Build;
import android.os.Bundle;
import android.os.Environment;
import android.provider.Settings;
import android.util.Log;
import android.view.View;

import androidx.annotation.NonNull;
import androidx.core.content.FileProvider;
import androidx.databinding.ObservableField;
import androidx.lifecycle.LiveData;
import androidx.lifecycle.MutableLiveData;

import com.tbruyelle.rxpermissions3.RxPermissions;
import com.xx.merchanthbh.data.http.requst.MineRequest;
import com.xx.merchanthbh.data.http.respons.OrderDetailBean;
import com.xx.merchanthbh.data.local.LocalData;
import com.xx.merchanthbh.data.staticdata.StaticData;
import com.xx.merchanthbh.ui.login.LoginActivity;
import com.xx.merchanthbh.ui.logoff.LogOffActivity;
import com.xx.merchanthbh.ui.order.OrderDetailViewModel;
import com.xx.merchanthbh.ui.phone.PhoneActivity;
import com.xx.merchanthbh.ui.pwd.PwdActivity;
import com.xx.merchanthbh.ui.userinfo.UserInfoActivity;
import com.xx.merchanthbh.ui.web.CommWabActivity;
import com.xx.merchanthbh.utils.RetrofitClient;
import com.xx.xxviewlibrary.base.AppManager;
import com.xx.xxviewlibrary.comm.CommTextDialog;
import com.xx.xxviewlibrary.comm.RefuseDialogBean;
import com.xx.xxviewlibrary.model.VersionBean;
import com.xx.xxviewlibrary.utils.CommUtilsKt;

import java.io.File;

import io.reactivex.rxjava3.core.Observer;
import io.reactivex.rxjava3.disposables.Disposable;
import io.reactivex.rxjava3.functions.Consumer;
import me.goldze.mvvmhabit.base.BaseViewModel;
import me.goldze.mvvmhabit.binding.command.BindingAction;
import me.goldze.mvvmhabit.binding.command.BindingCommand;
import me.goldze.mvvmhabit.http.ApiDisposableObserver;
import me.goldze.mvvmhabit.http.cookie.store.PersistentCookieStore;
import me.goldze.mvvmhabit.utils.RxUtils;
import me.goldze.mvvmhabit.utils.ToastUtils;
import okhttp3.ResponseBody;

public class MineViewModel extends BaseViewModel<MineRequest> {

   RxPermissions rxPermissions;

    //头像的绑定
    private MutableLiveData<String> avatarImageUrl = new MutableLiveData<>();
    //昵称的绑定
    public ObservableField<String> nickName = new ObservableField<>("");
    //创建时间的绑定
    public ObservableField<String> createTime = new ObservableField<>("");
    //职位的绑定
    public ObservableField<String> roleName = new ObservableField<>("");

    //版本号
    public ObservableField<String> versionName = new ObservableField<>("");


    public MutableLiveData<String> openInstall=new MutableLiveData<>("");

    public MineViewModel(@NonNull Application application) {
        super(application);
        model=new MineRequest();
    }


    private void setValueToNickName() {
        nickName.set(LocalData.getUser().getNickName());
        createTime.set("创建日期：" + CommUtilsKt.getTimeForm(LocalData.getUser().getCreateTime()));

        roleName.set(LocalData.getUser().getUserId() == LocalData.getMerchant().getUserId() ? "店长" : "店员");
        avatarImageUrl.setValue(LocalData.getUser().getAvatar());

    }

    //跳转注销账号界面
    public BindingCommand goLogOffUser = new BindingCommand(new BindingAction() {
        @Override
        public void call() {
            startActivity(LogOffActivity.class);
        }

    });


    /*头像回显*/
    public LiveData<String> getAvatarImageUrl() {
        return avatarImageUrl;
    }

    public void refreshNickName() {
        setValueToNickName();
    }

    //跳转修改密码界面
    public BindingCommand goChangePwd = new BindingCommand(new BindingAction() {
        @Override
        public void call() {
            startActivity(PwdActivity.class);
        }

    });
    //跳转修改手机号界面
    public BindingCommand goChangePhone = new BindingCommand(new BindingAction() {
        @Override
        public void call() {
            startActivity(PhoneActivity.class);
        }

    });

    public BindingCommand exitLogin = new BindingCommand(new BindingAction() {
        @Override
        public void call() {
            showCommTextDialog(new RefuseDialogBean("是否确定退出？", "确定", "取消"), new CommTextDialog.onAcceptCallBack() {
                @Override
                public void acceptBack() {
                    finish();
//                    startActivity(LoginActivity.class); // 跳转到登录页面
                    AppManager.getAppManager().finishAllActivityExThis(LoginActivity.class);
                }

                @Override
                public void refuseBack() {

                }
            });

        }
    });

    public void goUserinfo(View view) {
        startActivity(UserInfoActivity.class);
    }

    public void clearCookie(View view) {
        PersistentCookieStore p = new PersistentCookieStore(view.getContext());
        p.removeAllCookie();
        ToastUtils.showShort("清除缓存成功");
    }


    /**
     * 获取最新APK版本号
     *
     * @param view
     */
    public void checkVersion(View view) {


        model.checkVersion().compose(RxUtils.schedulersTransformer()) //线程调度
                .doOnSubscribe(MineViewModel.this)
                .doOnSubscribe(new Consumer<Disposable>() {
                    @Override
                    public void accept(Disposable disposable) throws Exception {
                    }
                }).subscribe(new ApiDisposableObserver<VersionBean>() {

                    @Override
                    public void onSuccess(VersionBean resultBean) {
                        if (CommUtilsKt.checkVersionUpdata(CommUtilsKt.getVersion(view.getContext()), resultBean.getAppVersion())) {


                            //不强制
                            if (resultBean.getPushFlag().equals("0")) {
                                showCommTextDialog(new RefuseDialogBean("是否前往更新", "确定", "取消", "更新提示"), new CommTextDialog.onAcceptCallBack() {
                                    @Override
                                    public void refuseBack() {

                                    }

                                    @Override
                                    public void acceptBack() {

                                        rxPermissions
                                                .request(Manifest.permission.WRITE_EXTERNAL_STORAGE)
                                                .subscribe(granted -> {
                                                    if (granted) { // Always true pre-M
                                                     /*   rxPermissions
                                                                .request(Manifest.permission.REQUEST_INSTALL_PACKAGES)
                                                                .subscribe(granteds -> {
                                                                    if (granteds) { // Always true pre-M

                                                                    } else {
                                                                        ToastUtils.showShort("请允许安装外部来源应用");
                                                                        openInstall.postValue("1");
                                                                    }
                                                                });*/
                                                        updataApk(view.getContext(), resultBean.getVersionFile(), view.getContext().getFilesDir().getPath() + resultBean.getVersionFile().substring(
                                                                resultBean.getVersionFile().lastIndexOf("/")));

                                                    } else {
                                                        ToastUtils.showShort("请开启文件相关权限");
                                                    }
                                                });

                                    }
                                });
                            } else {
                                showCommTextDialog(new RefuseDialogBean("请前往更新", "确定", null), new CommTextDialog.onAcceptCallBack() {
                                    @Override
                                    public void refuseBack() {
                                        finish();
                                    }

                                    @Override
                                    public void acceptBack() {

                                        rxPermissions
                                                .request(Manifest.permission.WRITE_EXTERNAL_STORAGE)
                                                .subscribe(granted -> {
                                                    if (granted) { // Always true pre-M
                                                       /* rxPermissions
                                                                .request(Manifest.permission.REQUEST_INSTALL_PACKAGES)
                                                                .subscribe(granteds -> {
                                                                    if (granteds) { // Always true pre-M

                                                                    } else {
                                                                        ToastUtils.showShort("请允许安装外部来源应用");
                                                                        openInstall.postValue("1");
                                                                    }
                                                                });*/
                                                        updataApk(view.getContext(), resultBean.getVersionFile(), view.getContext().getFilesDir().getPath() + resultBean.getVersionFile().substring(
                                                                resultBean.getVersionFile().lastIndexOf("/")));
                                                    } else {
                                                        ToastUtils.showShort("请开启文件相关权限");
                                                    }
                                                });

                                    }
                                });
                            }

                        } else {
                            if (view!=null)
                            {
                                ToastUtils.showShort("版本已是最新！");
                            }

                        }


                    }

                    @Override
                    public void onError(String Error) {
                    }
                });
    }


    /**
     * 下载APK
     *
     * @param context
     * @param url　下载地址
     * @param name　文件名字
     */
    public void updataApk(Context context, String url, String name) {
        /*执行传参方法*/
        showDialog("正在下载...");

        model.downFile(url, name).subscribe(new Observer<ResponseBody>() {
            @Override
            public void onSubscribe(@io.reactivex.rxjava3.annotations.NonNull Disposable d) {
                Log.e("下载","onSubscribe");
            }

            @Override
            public void onNext(@io.reactivex.rxjava3.annotations.NonNull ResponseBody responseBody) {

            }

            @Override
            public void onError(@io.reactivex.rxjava3.annotations.NonNull Throwable e) {
                ToastUtils.showShort("下载失败");
                dismissDialog();
            }

            @Override
            public void onComplete() {
                Log.e("下载要成功", "onComplete");
                dismissDialog();
                ToastUtils.showShort("下载成功");
                installApk(context, name);
            }
        });
    }
    //跳转安装ＡＰＰ
    private void installApk(Context context, String path) {
        Intent intent = new Intent(Intent.ACTION_VIEW);
        File file = new File(Uri.parse(path).getPath());
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.N) {
            intent.setFlags(Intent.FLAG_GRANT_READ_URI_PERMISSION);
            Uri uri = FileProvider.getUriForFile(context, "com.xx.merchanthbh.fileProvider", file);
            intent.setDataAndType(uri, "application/vnd.android.package-archive");
        } else {
            intent.setDataAndType(Uri.fromFile(file), "application/vnd.android.package-archive");
        }
        intent.addFlags(Intent.FLAG_ACTIVITY_NEW_TASK); // Adding the flag here
        context.startActivity(intent);
    }

    public void goProtocol(View view) {
        if (StaticData.Protocols.size() >= 3) {
            Bundle bundle = new Bundle();
            bundle.putString("title", "隐私条款");
            bundle.putString("URL", RetrofitClient.baseH5Url + StaticData.Protocols.get(2));
            startActivity(CommWabActivity.class, bundle);
        }

    }


}