package com.xx.merchanthbh.ui.order;

import android.os.Bundle;
import android.view.View;

import androidx.annotation.NonNull;
import androidx.lifecycle.Observer;

import com.google.android.material.tabs.TabLayout;
import com.scwang.smart.refresh.layout.api.RefreshLayout;
import com.scwang.smart.refresh.layout.listener.OnLoadMoreListener;
import com.scwang.smart.refresh.layout.listener.OnRefreshListener;
import com.xx.merchanthbh.BR;
import com.xx.merchanthbh.R;
import com.xx.merchanthbh.activity.adapter.OrderListAdapter;
import com.xx.merchanthbh.data.http.requst.OrderRequest;
import com.xx.merchanthbh.data.http.respons.OrderBean;
import com.xx.merchanthbh.databinding.ActivityOrderManagementBinding;
import com.xx.xxviewlibrary.base.xxBaseRecyclerViewAdapter;

import java.util.List;

import me.goldze.mvvmhabit.base.BaseActivity;

public class OrderActivity extends BaseActivity<ActivityOrderManagementBinding, OrderViewModel> implements OnRefreshListener, OnLoadMoreListener {
    @Override
    public int initContentView(Bundle savedInstanceState) {
        return R.layout.activity_order_management;
    }

    @Override
    public int initVariableId() {
        return BR.orderViewModel;
    }

    //    重写初始方法调用参数
    @Override
    public void initData() {
        super.initData();
        binding.refresh.setOnRefreshListener(this);
        binding.refresh.setOnLoadMoreListener(this);
        viewModel.orderListAdapter= new OrderListAdapter(this);
        viewModel.orderListAdapter.staticVisibility=true;
        binding.rvOrderList.setAdapter(viewModel.orderListAdapter);
        // 对列表遍历项设置点击事件
        viewModel.orderListAdapter.setOnItemClick(new xxBaseRecyclerViewAdapter.OnItemClick<OrderBean>() {
            /*返回位置参数*/
            @Override
            public void itemClickCalBack(int position, OrderBean data) {
                /*将上下文和位置参数给方法*/
                viewModel.goOrderDetail(viewModel.orderListAdapter, position);
            }
        });
        viewModel.loadMoreStatic.observe(this, new Observer<Integer>() {
            @Override
            public void onChanged(Integer it) {
                if (it == 1) {
                    /*隐藏recycleView和它的暂无数据列表*/
                    binding.rvOrderList.setVisibility(View.VISIBLE);
                    binding.llNoData.setVisibility(View.GONE);
                    /*结束加载*/
                    binding.refresh.finishLoadMore();
                } else if (it == 2) {
                    /*隐藏recycleView和它的暂无数据列表*/
                    binding.rvOrderList.setVisibility(View.VISIBLE);
                    binding.llNoData.setVisibility(View.GONE);
                    /*结束加载*/
                    binding.refresh.finishLoadMoreWithNoMoreData();
                }else if(it==3)
                {
                    /*显示recycleView和它的暂无数据列表*/
                    binding.rvOrderList.setVisibility(View.GONE);
                    binding.llNoData.setVisibility(View.VISIBLE);
                }
                binding.refresh.finishRefresh();
            }
        });
        //调接口
        viewModel.getOrderList();

        /*切换状态Tab*/
        binding.tabs.addOnTabSelectedListener(new TabLayout.OnTabSelectedListener() {
            @Override
            /*订单状态 1-待付款 2-已完成 3-已关闭*/
            public void onTabSelected(TabLayout.Tab tab) {
                // 重置页数
                viewModel.page = 1;
                // 重置 loadMoreStatic
                viewModel.loadMoreStatic.postValue(0);
                // 重置 SmartRefreshLayout 的状态
                binding.refresh.resetNoMoreData(); // 重置没有更多数据的状态
                binding.refresh.setNoMoreData(false); // 设置为不再有更多数据
                binding.refresh.finishLoadMore(); // 结束加载更多状态

                viewModel.orderListAdapter.mList.clear();
                switch (tab.getPosition()) {
                    case 0:
                        viewModel.orderStatus = "";
                        viewModel.orderListAdapter.staticVisibility=true;
                        viewModel.getOrderList();
                        break;
                    case 1:
                        viewModel.orderStatus = "1";
                        viewModel.orderListAdapter.staticVisibility=false;
                        viewModel.getOrderList();
                        break;
                    case 2:
                        viewModel.orderStatus = "2";
                        /*状态位存储留给详情页用*/
                        viewModel.orderListAdapter.staticVisibility=false;
                        viewModel.getOrderList();
                        break;
                    case 3:
                        viewModel.orderStatus = "3";
                        viewModel.orderListAdapter.staticVisibility=false;
                        viewModel.getOrderList();
                        break;
                }
            }

            @Override
            public void onTabUnselected(TabLayout.Tab tab) {
            }

            @Override
            public void onTabReselected(TabLayout.Tab tab) {
            }
        });
    }

    //    重写初始方法调用参数
    @Override
    public void initViewObservable() {
        super.initViewObservable();
    }

    @Override
    public OrderViewModel initViewModel() {
        OrderRequest lm = new OrderRequest();
        return new OrderViewModel(getApplication(), lm);
    }
    @Override
    public void onLoadMore(RefreshLayout refreshLayout) {
        viewModel.page++;
        viewModel.getOrderList();
    }

    @Override
    public void onRefresh(@NonNull RefreshLayout refreshLayout) {
        viewModel.page=1;
        viewModel.getOrderList();
        binding.refresh.setEnableFooterFollowWhenNoMoreData(true);
    }
}
