package com.xx.merchanthbh.ui.order;

import static com.xx.merchanthbh.utils.RetrofitClient.baseImgUrl;

import android.app.Application;
import android.util.Log;
import android.view.View;
import android.widget.ImageView;

import androidx.annotation.NonNull;
import androidx.databinding.ObservableField;
import androidx.lifecycle.LiveData;
import androidx.lifecycle.MutableLiveData;
import androidx.lifecycle.ViewModel;

import com.bumptech.glide.Glide;
import com.bumptech.glide.load.resource.bitmap.RoundedCorners;
import com.bumptech.glide.request.RequestOptions;
import com.xx.merchanthbh.data.http.requst.MerchantEnterRequst;
import com.xx.merchanthbh.data.http.requst.OrderDetailRequest;
import com.xx.merchanthbh.data.http.respons.MerchantBean;
import com.xx.merchanthbh.data.http.respons.OrderBean;
import com.xx.merchanthbh.data.http.respons.OrderDetailBean;
import com.xx.merchanthbh.data.local.LocalData;
import com.xx.merchanthbh.data.staticdata.StaticData;
import com.xx.merchanthbh.ui.merchantinfo.MerchantInfoViewModel;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

import io.reactivex.rxjava3.disposables.Disposable;
import io.reactivex.rxjava3.functions.Consumer;
import me.goldze.mvvmhabit.base.BaseViewModel;
import me.goldze.mvvmhabit.http.ApiDisposableObserver;
import me.goldze.mvvmhabit.utils.RxUtils;
import me.jessyan.autosize.utils.AutoSizeUtils;

public class OrderDetailViewModel extends BaseViewModel<OrderDetailRequest> {
    //    创建订单详情的商品列表实体对象
    public MutableLiveData<List<OrderDetailBean.CommodityLists>> orderDetailList = new MutableLiveData<>(new ArrayList<>());
    //   创建商户logo的实体对象
    private MutableLiveData<String> storeImageUrl = new MutableLiveData<>();

    //优惠判断
    MutableLiveData<List<OrderDetailBean.CouponLists>> CouponLists = new MutableLiveData<>();

    /*创建商品对象*/
    public OrderDetailBean orderDetailBean;
    //商品总价的绑定
    public ObservableField<Double> orderAmount = new ObservableField<>();
    //优惠金额的绑定
    public ObservableField<String> discountAmount = new ObservableField<>("");
    //赠品的绑定
    public ObservableField<String> giftName = new ObservableField<>("");
    //实/待付款的绑定
    public ObservableField<Double> actualPayment = new ObservableField<>();
    //会员姓名的绑定
    public ObservableField<String> memberNickname = new ObservableField<>("");
    //会员联系方式的绑定
    public ObservableField<String> memberPhone = new ObservableField<>("");
    //会员等级的绑定
    public ObservableField<String> gradeName = new ObservableField<>("");
    //订单编号的绑定
    public ObservableField<String> orderNumber = new ObservableField<>("");
    //创建时间的绑定
    public ObservableField<String> createTime = new ObservableField<>("");
    //付款时间的绑定
    public ObservableField<String> updateTime = new ObservableField<>("");
    //收银员的绑定
    public ObservableField<String> updateBy = new ObservableField<>("");
    //商铺名称的绑定
    public ObservableField<String> storeName = new ObservableField<>("");
    //总件数的绑定
    public ObservableField<String> quantity = new ObservableField<>("");

    //总件数的绑定
    public ObservableField<Integer> payMsgVisible = new ObservableField<>(View.GONE);

    public ObservableField<String> payStatic=new ObservableField<>("实付金额");


    /*声明要给接口传参的id*/
    public String businessId = "";

    public OrderDetailViewModel(@NonNull Application application) {
        super(application);
    }

    public OrderDetailViewModel(@NonNull Application application, OrderDetailRequest model) {
        super(application, model);
    }

    /**
     * 获取订单详情
     */
    public void getOrderDetailInfo() {
        model.getOrderDetailsInfoById(businessId).compose(RxUtils.schedulersTransformer()) //线程调度
                .doOnSubscribe(OrderDetailViewModel.this)
                .doOnSubscribe(new Consumer<Disposable>() {
                    @Override
                    public void accept(Disposable disposable) throws Exception {
                    }
                }).subscribe(new ApiDisposableObserver<OrderDetailBean>() {
                    @Override
                    public void onSuccess(OrderDetailBean resultBean) {
                        orderDetailList.postValue(resultBean.getCommodityList());

                        /*商户图片赋值*/
                        storeImageUrl.setValue(resultBean.getMerchant().getCompanyLogoFile().getFilePath());
                        Log.v("还在viewModel滞留的图片", String.valueOf(storeImageUrl));
                        /*商品对象进行赋值*/
                        orderDetailBean = resultBean;
                        Log.v("商品对象里面的商品信息:", String.valueOf(orderDetailBean.getCommodityList()));
                        /*商品总价赋值*/
                        orderAmount.set(resultBean.getOrderAmount());

                        if (resultBean.getOrderStatus()==2)
                        {
                            /* 已完成 实付款赋值*/
                            actualPayment.set(resultBean.getActualPayment());
                            payStatic.set("实付金额");
                        }else {
                            actualPayment.set(resultBean.getWaitPayment());
                            payStatic.set("待付金额");
                        }

                        /*会员姓名赋值*/
                        memberNickname.set(resultBean.getMember().getMemberNickname());
                        /*会员联系方式赋值*/
                        memberPhone.set(resultBean.getMember().getMemberPhone());
                        /*会员等级赋值*/
                        gradeName.set(resultBean.getMember().getGradeName());
                        /*订单编号赋值*/
                        orderNumber.set(resultBean.getOrderNumber());
                        /*创建时间赋值*/
                        createTime.set(resultBean.getCreateTime());
                        /*付款时间赋值*/
                        updateTime.set(resultBean.getUpdateTime());
                        /*收银员赋值*/
                        updateBy.set(resultBean.getUpdateBy());
                        /*商铺名称赋值*/
                        storeName.set(resultBean.getMerchant().getStoreName());
                        /*总件数赋值*/
                        quantity.set(String.valueOf(resultBean.getQuantity()));

                        CouponLists.postValue(resultBean.getCouponList());

                    }

                    @Override
                    public void onError(String Error) {

                    }

                });
    }


    /*商户图片回显*/
    public LiveData<String> getStoreImageUrl() {
        return storeImageUrl;
    }
}
