package com.xx.merchanthbh.ui.ordercreate;

import android.app.Application;
import android.view.View;

import androidx.annotation.NonNull;
import androidx.databinding.ObservableField;
import androidx.lifecycle.MutableLiveData;
import androidx.navigation.NavController;
import androidx.navigation.Navigation;

import com.xx.merchanthbh.R;
import me.goldze.mvvmhabit.base.ListBaseViewModel;
import com.xx.merchanthbh.data.http.requst.OrderCreateRequest;
import com.xx.merchanthbh.data.http.respons.MemberInfoBean;
import com.xx.merchanthbh.data.http.respons.ProductForOrderBean;

import java.util.ArrayList;
import java.util.List;

import io.reactivex.rxjava3.disposables.Disposable;
import io.reactivex.rxjava3.functions.Consumer;
import me.goldze.mvvmhabit.http.ApiDisposableObserver;
import me.goldze.mvvmhabit.http.ApiDisposablePageObserver;
import me.goldze.mvvmhabit.utils.RxUtils;
import me.goldze.mvvmhabit.utils.StringUtils;
import me.goldze.mvvmhabit.utils.ToastUtils;

public class OrderCreateViewModel extends ListBaseViewModel<OrderCreateRequest> {

    public OrderSelectProductAdapter adapter;

    public OrderProductAdapter productAdapter;

    public ObservableField<String> phone = new ObservableField<>("");

    public ObservableField<Integer> msg = new ObservableField<>(View.GONE);

    public ObservableField<MemberInfoBean> memberInfoBean = new ObservableField<>(new MemberInfoBean());

    public List<ProductForOrderBean> orderProductList=new ArrayList<>();

    public MutableLiveData<Double>  total=new MutableLiveData<>(0.0d);

    public ObservableField<String> searchWord=new ObservableField<>("");

    public ObservableField<Integer> creatVisibility=new ObservableField<>(View.GONE);

    public OrderCreateViewModel(@NonNull Application application) {

        super(application);
        model=new OrderCreateRequest();
    }

    public OrderCreateViewModel(@NonNull Application application, OrderCreateRequest model) {
        super(application, model);
    }

    /**
     * 获取会员信息
     * @param view
     */
    public void getMemberByPhone(View view)
    {

        if (StringUtils.isEmpty(phone.get()))
        {
            ToastUtils.showShort("请输入会员手机号");
            return;
        }

        model.getMemberByPhone(phone.get()). compose(RxUtils.schedulersTransformer()) //线程调度
//                        .compose(RxUtils.exceptionTransformer()) // 网络错误的异常转换, 这里可以换成自己的ExceptionHandle
            .doOnSubscribe(OrderCreateViewModel.this)
            .doOnSubscribe(new Consumer<Disposable>() {
                @Override
                public void accept(Disposable disposable) throws Exception {
                }
            }).subscribe(new ApiDisposableObserver<MemberInfoBean>() {
                    @Override
                    public void onSuccess(MemberInfoBean resultBean) {
                        msg.set(View.VISIBLE);
                        memberInfoBean.set(resultBean);
                    }

                    @Override
                    public void onError(String Error) {

                    }
                });
    }

    /**
     * 获取产品列表
     */
    public void getProductList()
    {
        model.getProductForPrder(searchWord.get(),page). compose(RxUtils.schedulersTransformer()) //线程调度
//                        .compose(RxUtils.exceptionTransformer()) // 网络错误的异常转换, 这里可以换成自己的ExceptionHandle
                .doOnSubscribe(OrderCreateViewModel.this)
                .doOnSubscribe(new Consumer<Disposable>() {
                    @Override
                    public void accept(Disposable disposable) throws Exception {
                    }
                }).subscribe(new ApiDisposablePageObserver<ProductForOrderBean>() {
                    @Override
                    public void onSuccess(List<ProductForOrderBean> resultBean) {
                        
                        if (page==1)
                        {
                            adapter.mList=resultBean;
                        }else {
                            adapter.mList.addAll(resultBean);
                        }
                        adapter.notifyDataSetChanged();
                    }

                    @Override
                    public void onError(String Error) {

                    }

                    @Override
                    public void getTotal(int total) {
                        if (total==0)
                        {
                            loadMoreStatic.postValue(3);
                        }else if (adapter.mList.size()>=total)
                        {
                            loadMoreStatic.postValue(2);
                        }else {
                            loadMoreStatic.postValue(1);
                        }
                    }
                });
    }


    /**
     * 选择商品页面
     * @param view
     */
    public void selectProduct(View view)
    {
        NavController navController= Navigation.findNavController(view);
        navController.navigate(R.id.action_orderCreatFragment_to_selectProductFragment);
    }


    /**
     * 返回订单创建页并获取订单产品
     * @param view
     */
    public void getOrderProductList(View view)
    {
        orderProductList=adapter.getSelectList();
        NavController navController= Navigation.findNavController(view);
        navController.navigateUp();
        getTotalMoney();
         productAdapter.mList =  orderProductList;

//        navController.navigate(R.id.action_orderCreatFragment_to_selectProductFragment);
       
    }

    public void getTotalMoney()
    {
        /*if (orderProductList.size()<=0)
        {
            creatVisibility.set(View.GONE);
        }else {
            creatVisibility.set(View.VISIBLE);
        }
        double money=0.0;
        for (ProductForOrderBean bean:orderProductList)
        {
            money=money+bean.reCommodityQuantity()*bean.getPrice();
        }*/
        total.postValue(0.0);

    }

    public void createOrder(View view )
    {
        if (orderProductList.size()<=0)
        {
            ToastUtils.showShort("请选择商品");
            return;
        }
        model.createOrder(memberInfoBean.get(),orderProductList).compose(RxUtils.schedulersTransformer()) //线程调度
//                        .compose(RxUtils.exceptionTransformer()) // 网络错误的异常转换, 这里可以换成自己的ExceptionHandle
            .doOnSubscribe(OrderCreateViewModel.this)
            .doOnSubscribe(new Consumer<Disposable>() {
                @Override
                public void accept(Disposable disposable) throws Exception {
                }
            }).subscribe(new ApiDisposableObserver<Boolean>() {

                    @Override
                    public void onSuccess(Boolean resultBean) {
                        finish();
                    }

                    @Override
                    public void onError(String Error) {

                    }
                });
    }

    /**
     * 筛选商品
     * @param view
     */
    public void searchGoods(View view )
    {
        page=1;
        getProductList();
    }


}
