package com.xx.merchanthbh.ui.phone;

import static me.goldze.mvvmhabit.utils.Utils.Interceptor_TOKEN;

import android.app.Application;
import android.text.TextUtils;
import android.util.Log;

import androidx.annotation.NonNull;
import androidx.databinding.ObservableField;

import com.xx.merchanthbh.data.http.requst.PhoneRequest;
import com.xx.merchanthbh.data.local.LocalData;
import com.xx.merchanthbh.ui.login.LoginActivity;
import com.xx.merchanthbh.ui.pwd.ForgetPwdViewModel;

import java.util.Timer;
import java.util.TimerTask;

import io.reactivex.rxjava3.disposables.Disposable;
import io.reactivex.rxjava3.functions.Consumer;
import me.goldze.mvvmhabit.base.BaseViewModel;
import me.goldze.mvvmhabit.binding.command.BindingAction;
import me.goldze.mvvmhabit.binding.command.BindingCommand;
import me.goldze.mvvmhabit.http.ApiDisposableObserver;
import me.goldze.mvvmhabit.utils.RxUtils;
import me.goldze.mvvmhabit.utils.ToastUtils;

public class PhoneViewModel extends BaseViewModel<PhoneRequest> {
    //当前绑定手机号
    public ObservableField<String> currentPhone = new ObservableField<>("");
    //更换的手机号
    public ObservableField<String> changePhoneNumber = new ObservableField<>("");
    //验证码
    public ObservableField<String> code = new ObservableField<>("");

    /**
     * 获取验证码按钮文字
     */
    public ObservableField<String> getCodeStr=new ObservableField<>("获取验证码");
    /**
     * 获取验证码按钮可点击状态
     */
    public ObservableField<Boolean> codeClick=new ObservableField<>(true);

    public PhoneViewModel(@NonNull Application application) {
        super(application);
    }

    public PhoneViewModel(@NonNull Application application, PhoneRequest model) {
        super(application, model);
    }
    /*设置当前绑定的手机号*/
    private void setValueToNickName() {
        currentPhone.set(LocalData.getUser().getPhonenumber());
    }
    public void refreshNickName() {
        setValueToNickName();
    }

    // 获取验证码
    public BindingCommand getCode = new BindingCommand(new BindingAction() {
        @Override
        public void call() {

            if (TextUtils.isEmpty(changePhoneNumber.get())) {
                ToastUtils.showShort("请输入正确的手机号！");
                return;
            }
            model.getCode(changePhoneNumber.get())
                    .compose(RxUtils.schedulersTransformer()) //线程调度
                    .doOnSubscribe(PhoneViewModel.this)
                    .doOnSubscribe(new Consumer<Disposable>() {
                        @Override
                        public void accept(Disposable disposable) throws Exception {
                            codeClick.set(false);
                            showDialog("正在获取验证码");

                        }
                    }).subscribe(new ApiDisposableObserver<String>() {
                        @Override
                        public void onSuccess(String resultBean) {
//                            ToastUtils.showShort("已经发送成功");
                            codeCountDown();
                            ToastUtils.showShort(resultBean);
                            dismissDialog();
                        }

                        @Override
                        public void onError(String Error) {
                            dismissDialog();
                            codeClick.set(true);
                        }


                    });
        }
    });

    /**
     * 获取验证码倒计时
     */
    public void codeCountDown()
    {
        final int[] second = {60};
        Timer timer=new Timer();
        timer.schedule(new TimerTask() {
            @Override
            public void run() {
                second[0]--;
                if (second[0] >0)
                {
                    getCodeStr.set("重新获取（"+ second[0] +")");
                }else {
                    getCodeStr.set("获取验证码");
                    codeClick.set(true);
                    this.cancel();
                    timer.cancel();

                }
            }
        },1000,1000);
    }


    /*调用更改手机号接口*/
    // 触发确认按钮
    public BindingCommand changePhoneA = new BindingCommand(new BindingAction() {
        @Override
        public void call() {
            if (TextUtils.isEmpty(changePhoneNumber.get().toString())) {
                ToastUtils.showShort("请输入手机号！");
            } else if (TextUtils.isEmpty(code.get().toString())) {
                ToastUtils.showShort("请输入验证码！");
            } else {
                model.ChangePhone(changePhoneNumber.get().toString(), code.get().toString())
                        .compose(RxUtils.schedulersTransformer()) //线程调度
//                        .compose(RxUtils.exceptionTransformer()) // 网络错误的异常转换, 这里可以换成自己的ExceptionHandle
                        .doOnSubscribe(PhoneViewModel.this)
                        .doOnSubscribe(new Consumer<Disposable>() {
                            @Override
                            public void accept(Disposable disposable) throws Exception {
                                showDialog("正在请求...");
                            }
                        }).subscribe(new ApiDisposableObserver<String>() {
                            @Override
                            public void onSuccess(String resultBean) {
                                //是指token
                                Interceptor_TOKEN = "Bearer " + resultBean;
                                finish();
                                /*待确认!!!!!!!!!!!!!*/
                                startActivity(LoginActivity.class);
                            }

                            @Override
                            public void onError(String Error) {
                                dismissDialog();
                            }

                        });
            }
        }
    });
}
