package com.xx.merchanthbh.ui.point;

import android.app.AlertDialog;
import android.app.Application;
import android.content.DialogInterface;
import android.util.Log;
import android.view.Gravity;
import android.view.View;
import android.widget.LinearLayout;
import android.widget.NumberPicker;
import android.widget.TextView;

import androidx.annotation.NonNull;
import androidx.databinding.ObservableField;
import androidx.lifecycle.LiveData;
import androidx.lifecycle.MutableLiveData;

import com.xx.merchanthbh.R;
import com.xx.merchanthbh.activity.adapter.StorePointAdapter;
import com.xx.merchanthbh.data.http.requst.StorePointsRequest;
import com.xx.merchanthbh.data.http.respons.IntegralTypeBean;
import com.xx.merchanthbh.data.http.respons.MerchantBean;
import com.xx.merchanthbh.data.http.respons.MerchantPointBean;
import com.xx.merchanthbh.data.local.LocalData;
import com.xx.merchanthbh.data.staticdata.StaticData;
import com.xx.merchanthbh.dialog.AppealTypeListDialog;
import com.xx.merchanthbh.dialog.IntegeralTypeListDialog;
import com.xx.merchanthbh.dialog.data.TextListProvider;
import com.xx.merchanthbh.ui.merchantinfo.MerchantInfoViewModel;
import com.xx.xxviewlibrary.base.xxBaseDialog;

import java.util.ArrayList;
import java.util.Calendar;
import java.util.List;

import io.reactivex.rxjava3.disposables.Disposable;
import io.reactivex.rxjava3.functions.Consumer;
import me.goldze.mvvmhabit.base.BaseViewModel;
import me.goldze.mvvmhabit.base.onDataSelect;
import me.goldze.mvvmhabit.http.ApiDisposableObserver;
import me.goldze.mvvmhabit.utils.RxUtils;
import me.jessyan.autosize.utils.AutoSizeUtils;

public class StorePointsViewModel extends BaseViewModel<StorePointsRequest> {

    StorePointAdapter storePointAdapter;
    //   创建商户logo的实体对象
    private MutableLiveData<String> storeImageUrl = new MutableLiveData<>(LocalData.getMerchant().getLogoFile().getFilePath());
    /*创建类型数据字典实体对象*/
    public List<IntegralTypeBean> integralTypeBeanArrayList = new ArrayList<IntegralTypeBean>();
    /*创建类型的label*/
    public ObservableField<String> dictLabel = new ObservableField<>("");
    /*筛选类型的dictValue*/
    public String dictValue = null;
    /*筛选日期的selectedDate*/
    public String selectedDate = null;
    //头像的绑定
    private MutableLiveData<String> avatarImageUrl = new MutableLiveData<>(LocalData.getUser().getAvatar());

    //    创建积分明细列表实体对象
    public MutableLiveData<List<MerchantPointBean>> merchantPointList = new MutableLiveData<>(new ArrayList<>());

    //公司名称的绑定
    public ObservableField<String> companyName = new ObservableField<>(LocalData.getMerchant().getStoreName());
    //累计积分的绑定
    public ObservableField<String> variableIntegral = new ObservableField<>(LocalData.getMerchant().getIntegral().toString());

    public StorePointsViewModel(@NonNull Application application) {
        super(application);
    }

    public StorePointsViewModel(@NonNull Application application, StorePointsRequest model) {
        super(application, model);
    }


    /**
     * 获取详情
     */
    public void getMerchantInfo()
    {

        model.getMerchantInfoById().compose(RxUtils.schedulersTransformer()) //线程调度
                .doOnSubscribe(StorePointsViewModel.this)
                .doOnSubscribe(new Consumer<Disposable>() {
                    @Override
                    public void accept(Disposable disposable) throws Exception {
                    }
                }).subscribe(new ApiDisposableObserver<MerchantBean>() {
                    @Override
                    public void onSuccess(MerchantBean resultBean) {

                    }

                    @Override
                    public void onError(String Error) {

                    }

                });
    }
    /*商户图片回显*/
    public LiveData<String> getStoreImageUrl() {
        return storeImageUrl;
    }


    //调用积分明细的接口信息
    public void getStorePointsList() {
        model.getMerchantPointList(dictValue,selectedDate)
                .compose(RxUtils.schedulersTransformer()) //线程调度
                .doOnSubscribe(StorePointsViewModel.this)
                .doOnSubscribe(new Consumer<Disposable>() {
                    @Override
                    public void accept(Disposable disposable) throws Exception {
                    }
                }).subscribe(new ApiDisposableObserver<List<MerchantPointBean>>() {
                    @Override
                    public void onSuccess(List<MerchantPointBean> resultBean) {
                       /*存值*/
                        merchantPointList.postValue(resultBean);
                        storePointAdapter.mList = resultBean;
                        /*如果搜索的值条数为0则展示暂无数据图标*/
                        if (resultBean.size()==0){
                            StaticData.PointData=1;
                        }else {
                            StaticData.PointData=0;
                        }
                        storePointAdapter.notifyDataSetChanged();

                    }

                    @Override
                    public void onError(String Error) {
                        dismissDialog();
                    }


                });
    }


    /*筛选-获取积分类型列表(数据字典)*/
    public void getIntegralTypeList() {
        model.getIntegralTypeList()
                .compose(RxUtils.schedulersTransformer()) //线程调度
                .doOnSubscribe(StorePointsViewModel.this)
                .doOnSubscribe(new Consumer<Disposable>() {
                    @Override
                    public void accept(Disposable disposable) throws Exception {
                    }
                }).subscribe(new ApiDisposableObserver<List<IntegralTypeBean>>() {
                    @Override
                    public void onSuccess(List<IntegralTypeBean> resultBean) {
                        /*清空类型数据列表*/
                        integralTypeBeanArrayList.clear();
                        /*将接口的数据字典放入*/
                        integralTypeBeanArrayList.addAll(resultBean);
                    }

                    @Override
                    public void onError(String Error) {
                        dismissDialog();
                    }
                });
    }


    /*类型选择*/
    public void openType(View view) {
        /*创建弹窗的adapter遍历*/
        IntegeralTypeListDialog dialoh = new IntegeralTypeListDialog(view.getContext(), integralTypeBeanArrayList);
        dialoh.setDialogClickListener(new xxBaseDialog.onDialogClickListener<TextListProvider>() {
            /*最后点击确定以后执行set*/
            @Override
            public void dialogClickBack(int code, TextListProvider data) {
                /*做空指针异常情况处理*/
                if (data != null) {
                    /*选择以后把所在的label给set进去*/
                    dictLabel.set(data.providerText());
                    /*选择以后把所在的value给set进去*/
                    dictValue = data.ProviderId();
                    /*调接口*/
                    getStorePointsList();
                }
            }
        });
        /*展示弹窗*/
        dialoh.show();
    }

    /*日期选择*/
    public void openDate(View view) {

      /*  Calendar calendar=Calendar.getInstance();
        int year = calendar.get(Calendar.YEAR);
        int month = calendar.get(Calendar.MONTH);
        showDataDialog(year, month, 0, new onDataSelect() {
            @Override
            public void reData(String dataStr) {

            }
        });*/

        // 创建一个AlertDialog.Builder
       AlertDialog.Builder builder = new AlertDialog.Builder(view.getContext());

        // 获取当前日期
        Calendar calendar = Calendar.getInstance();
        int year = calendar.get(Calendar.YEAR);
        int month = calendar.get(Calendar.MONTH);

        // 创建一个布局视图
        LinearLayout layout = new LinearLayout(view.getContext());
        layout.setOrientation(LinearLayout.HORIZONTAL);
        layout.setGravity(Gravity.CENTER);

        TextView tv=new TextView(view.getContext());
        tv.setText("年");
        tv.setTextColor(view.getContext().getColor(R.color.black));
        tv.setTextSize(18);

        TextView tvm=new TextView(view.getContext());
        tvm.setText("月");
        tvm.setTextColor(view.getContext().getColor(R.color.black));
        tvm.setTextSize(18);

        // 创建年份的NumberPicker
        final NumberPicker yearPicker = new NumberPicker(view.getContext());
        //*设置最小年份*/
        yearPicker.setMinValue(1900);
        //*设置最大年份*/
        yearPicker.setMaxValue(year);
        //*设置默认选中的年份*
        yearPicker.setValue(year);
        layout.addView(yearPicker);
        layout.addView(tv);
        // 创建月份的NumberPicker
        final NumberPicker monthPicker = new NumberPicker(view.getContext());
        //*设置最小月份*//*
        monthPicker.setMinValue(1);
        //*设置最大月份*//*
        monthPicker.setMaxValue(12);
        //*设置默认选中的月份*//*
        monthPicker.setValue(month + 1);
        layout.addView(monthPicker);
        layout.addView(tvm);

        //*设置AlertDialog的标题*//*
        builder.setTitle("日期选择")
                .setView(layout)
                .setPositiveButton("确定", new DialogInterface.OnClickListener() {
                    @Override
                    public void onClick(DialogInterface dialogInterface, int i) {
                        // 在这里选择年份和月份
                        int selectedYear = yearPicker.getValue();
                        int selectedMonth = monthPicker.getValue();
                        String formattedMonth = String.format("%02d", selectedMonth);
                        Log.v("这是年份呀aaaaaaa", String.valueOf(selectedYear));
                        Log.v("这是月份呀bbbbbbb", String.valueOf(selectedMonth));
                        //*将选择的年份和月份进行拼接*//*
                        selectedDate = selectedYear + "-" + formattedMonth;
                        Log.v("拼接后的日期aaaa", selectedDate);
                        //*调接口*//*
                        getStorePointsList();

                    }
                }).setNegativeButton("取消", new DialogInterface.OnClickListener() {
                    @Override
                    public void onClick(DialogInterface dialogInterface, int i) {
                        // 取消选择
                    }
                });

        // 创建并显示AlertDialog
        AlertDialog alertDialog = builder.create();
        alertDialog.show();

    }
}

