package com.xx.merchanthbh.ui.productmanager;

import android.app.Application;
import android.view.View;

import androidx.annotation.NonNull;
import androidx.databinding.ObservableField;

import me.goldze.mvvmhabit.base.ListBaseViewModel;

import com.xx.merchanthbh.data.http.requst.ProductManagerRequst;
import com.xx.merchanthbh.data.http.respons.ProductListBean;
import com.xx.merchanthbh.ui.addproduct.AddProductActivity;
import com.xx.xxviewlibrary.comm.CommTextDialog;
import com.xx.xxviewlibrary.comm.RefuseDialogBean;

import java.util.List;

import io.reactivex.rxjava3.disposables.Disposable;
import io.reactivex.rxjava3.functions.Consumer;
import me.goldze.mvvmhabit.http.ApiDisposableObserver;
import me.goldze.mvvmhabit.http.ApiDisposablePageObserver;
import me.goldze.mvvmhabit.utils.RxUtils;

public class ProductManagerViewModel extends ListBaseViewModel<ProductManagerRequst> {


    public String listStatic = null;
    public ProductListAdapter listAdapter;

    //时间顺序标识 0-时间降序,1-时间升序
    public String sortRules = "0";

    public ObservableField<String> timeStr = new ObservableField<>("时间降序");

    public ProductManagerViewModel(@NonNull Application application, ProductManagerRequst model) {
        super(application, model);
    }


    /**
     * 获取商品列表
     */
    public void getProductList() {


        model.getProductList(listStatic, sortRules, page).compose(RxUtils.schedulersTransformer()) //线程调度
//                        .compose(RxUtils.exceptionTransformer()) // 网络错误的异常转换, 这里可以换成自己的ExceptionHandle
                .doOnSubscribe(ProductManagerViewModel.this)
                .doOnSubscribe(new Consumer<Disposable>() {
                    @Override
                    public void accept(Disposable disposable) throws Exception {
                        showDialog("");
                    }
                }).subscribe(new ApiDisposablePageObserver<ProductListBean>() {

                    @Override
                    public void onSuccess(List<ProductListBean> resultBean) {
                        dismissDialog();
                        if (page == 1) {
                            listAdapter.mList = resultBean;
                        } else {
                            listAdapter.mList.addAll(resultBean);
                        }
                        listAdapter.notifyDataSetChanged();
                    }

                    @Override
                    public void onError(String Error) {
                        dismissDialog();
                    }

                    @Override
                    public void getTotal(int total) {
                        if (total == 0) {
                            loadMoreStatic.postValue(3);
                        } else if (listAdapter.mList.size() >= total) {
                            loadMoreStatic.postValue(2);
                        } else {
                            loadMoreStatic.postValue(1);
                        }
                    }
                });
    }


    public void deleteClick(ProductListBean bean) {

        showCommTextDialog(new RefuseDialogBean("删除后商品不可恢复，是否继续", "确定", "取消", "提示"), new CommTextDialog.onAcceptCallBack() {
            @Override
            public void acceptBack() {
                model.deleteProduct(bean.getBusinessId()).compose(RxUtils.schedulersTransformer()) //线程调度
//                        .compose(RxUtils.exceptionTransformer()) // 网络错误的异常转换, 这里可以换成自己的ExceptionHandle
                        .doOnSubscribe(ProductManagerViewModel.this)
                        .doOnSubscribe(new Consumer<Disposable>() {
                            @Override
                            public void accept(Disposable disposable) throws Exception {
                            }
                        }).subscribe(new ApiDisposableObserver<Integer>() {

                            @Override
                            public void onSuccess(Integer resultBean) {
                                listAdapter.mList.remove(bean);
                                listAdapter.notifyDataSetChanged();
                            }

                            @Override
                            public void onError(String Error) {

                            }
                        });
            }

            @Override
            public void refuseBack() {

            }
        });

    }

    /**
     * 修改商品状态
     *
     * @param bean
     * @param statics
     */
    public void changeProductStaticClick(ProductListBean bean, String statics) {

        if (statics.equals("3")) {
            String main;
            ;
            if (bean.isAllowShelf().equals("1")) {
                main = "编辑商品后需要商城审核，是否继续";
            } else {
                main = "是否将商品状态变为【已上架】";
            }
            showCommTextDialog(new RefuseDialogBean(main, "确定", "取消", "提示"), new CommTextDialog.onAcceptCallBack() {
                @Override
                public void acceptBack() {

                    if (bean.isAllowShelf().equals("1")) {
                        changeProductStatic(bean, "2");
                    } else {
                        changeProductStatic(bean, statics);
                    }

                }

                @Override
                public void refuseBack() {

                }
            });
        } else if (statics.equals("4")) {
            showCommTextDialog(new RefuseDialogBean("是否确认下架商品?", "确定", "取消"), new CommTextDialog.onAcceptCallBack() {
                @Override
                public void acceptBack() {
                    changeProductStatic(bean, statics);
                }

                @Override
                public void refuseBack() {

                }
            });

        } else {
                changeProductStatic(bean, statics);
        }


    }

    public void changeProductStatic(ProductListBean bean, String statics) {
        model.putProductStatic(bean.getBusinessId(), statics).compose(RxUtils.schedulersTransformer()) //线程调度
//                        .compose(RxUtils.exceptionTransformer()) // 网络错误的异常转换, 这里可以换成自己的ExceptionHandle
                .doOnSubscribe(ProductManagerViewModel.this)
                .doOnSubscribe(new Consumer<Disposable>() {
                    @Override
                    public void accept(Disposable disposable) throws Exception {
                    }
                }).subscribe(new ApiDisposableObserver<Integer>() {

                    @Override
                    public void onSuccess(Integer resultBean) {
                        listAdapter.mList.remove(bean);
                        listAdapter.notifyDataSetChanged();
                    }

                    @Override
                    public void onError(String Error) {

                    }
                });
    }


    public View.OnClickListener goadd = new View.OnClickListener() {
        @Override
        public void onClick(View view) {
            startActivity(AddProductActivity.class);
        }
    };


}
