package com.xx.merchanthbh.ui.pwd;

import static me.goldze.mvvmhabit.utils.Utils.Interceptor_TOKEN;

import android.app.Application;
import android.text.TextUtils;

import androidx.annotation.NonNull;
import androidx.databinding.ObservableField;

import com.xx.merchanthbh.data.http.requst.ForgetPwdRequest;
import com.xx.merchanthbh.ui.login.LoginActivity;

import java.util.Timer;
import java.util.TimerTask;

import io.reactivex.rxjava3.disposables.Disposable;
import io.reactivex.rxjava3.functions.Consumer;
import me.goldze.mvvmhabit.base.BaseViewModel;
import me.goldze.mvvmhabit.binding.command.BindingAction;
import me.goldze.mvvmhabit.binding.command.BindingCommand;
import me.goldze.mvvmhabit.http.ApiDisposableObserver;
import me.goldze.mvvmhabit.utils.RxUtils;
import me.goldze.mvvmhabit.utils.ToastUtils;

public class ForgetPwdViewModel extends BaseViewModel<ForgetPwdRequest> {
    //手机号绑定
    public ObservableField<String> phone = new ObservableField<>("");
    //验证码绑定
    public ObservableField<String> code = new ObservableField<>("");
    //密码绑定
    public ObservableField<String> password = new ObservableField<>("");

    //重复密码绑定
    public ObservableField<String> repeatPassword = new ObservableField<>("");
    /**
     * 获取验证码按钮文字
     */
    public ObservableField<String> getCodeStr=new ObservableField<>("获取验证码");
    /**
     * 获取验证码按钮可点击状态
     */
    public ObservableField<Boolean> codeClick=new ObservableField<>(true);
    public ForgetPwdViewModel(@NonNull Application application) {
        super(application);
    }

    public ForgetPwdViewModel(@NonNull Application application, ForgetPwdRequest model) {
        super(application, model);
    }
    // 验证手机号格式的方法
    private boolean isPhoneNumberValid(String phoneNumber) {
        // 使用正则表达式验证手机号格式
        String regex = "^1[3456789]\\d{9}$";
        return phoneNumber.matches(regex);
    }
    // 获取验证码
    public BindingCommand getCode = new BindingCommand(new BindingAction() {
        @Override
        public void call() {

            String phoneNumber = phone.get().toString().trim();
            if (TextUtils.isEmpty(phoneNumber)) {
                ToastUtils.showShort("请输入手机号！");
                return;
            } else if(!isPhoneNumberValid(phoneNumber)) {
                ToastUtils.showShort("请输入正确的手机号！");
                return;
            }
            model.getCode(phone.get().toString())
                    .compose(RxUtils.schedulersTransformer()) //线程调度
                    .doOnSubscribe(ForgetPwdViewModel.this)
                    .doOnSubscribe(new Consumer<Disposable>() {
                        @Override
                        public void accept(Disposable disposable) throws Exception {

                            showDialog("正在获取验证码");
                            codeClick.set(false);
                        }
                    }).subscribe(new ApiDisposableObserver<String>() {
                        @Override
                        public void onSuccess(String resultBean) {
                            codeCountDown();
                            ToastUtils.showShort(resultBean);
                            dismissDialog();
                        }

                        @Override
                        public void onError(String Error) {

                            codeClick.set(true);
                            dismissDialog();
                        }


                    });
        }
    });

    /**
     * 获取验证码倒计时
     */
    public void codeCountDown()
    {
        final int[] second = {60};
        Timer timer=new Timer();
        timer.schedule(new TimerTask() {
            @Override
            public void run() {
                second[0]--;
                if (second[0] >0)
                {
                    getCodeStr.set("重新获取（"+ second[0] +")");
                }else {
                    getCodeStr.set("获取验证码");
                    codeClick.set(true);
                    this.cancel();
                    timer.cancel();

                }
            }
        },1000,1000);
    }
    // 密码是否满足要求的方法
    private boolean passwordMatchesRequirements(String password) {
        // 使用正则表达式验证密码是否包含至少一个大写字母和一个小写字母
        String regex = "^(?=.*[a-z])(?=.*[A-Z]).+$";
        return password.matches(regex);
    }
    // 触发确认按钮
    public BindingCommand forgetPwd = new BindingCommand(new BindingAction() {
        @Override
        public void call() {
            if (TextUtils.isEmpty(phone.get().toString())) {
                ToastUtils.showShort("请输入手机号！");
            } else if (TextUtils.isEmpty(code.get().toString())) {
                ToastUtils.showShort("请输入验证码！");
            } else if (TextUtils.isEmpty(password.get().toString())) {
                ToastUtils.showShort("请输入登录密码！");
            }else if (password.get().length() < 8 || password.get().length() > 20) {
                ToastUtils.showShort("密码长度8-20位,需要同时包含大小写字母和数字");
            }else if (!passwordMatchesRequirements(password.get())) {
                ToastUtils.showShort("密码长度8-20位,需要同时包含大小写字母和数字");
            } else if (TextUtils.isEmpty(repeatPassword.get().toString())) {
                ToastUtils.showShort("请再次输入登录密码！");
            } else if (!password.get().toString().equals(repeatPassword.get().toString())) {
                ToastUtils.showShort("前后密码不一致！");
            } else {
                model.ForegetPwd(phone.get().toString(), password.get().toString(),code.get().toString())
                        .compose(RxUtils.schedulersTransformer()) //线程调度
//                        .compose(RxUtils.exceptionTransformer()) // 网络错误的异常转换, 这里可以换成自己的ExceptionHandle
                        .doOnSubscribe(ForgetPwdViewModel.this)
                        .doOnSubscribe(new Consumer<Disposable>() {
                            @Override
                            public void accept(Disposable disposable) throws Exception {
                                showDialog("正在请求...");
                            }
                        }).subscribe(new ApiDisposableObserver<String>() {
                            @Override
                            public void onSuccess(String resultBean) {
                                //是指token
                                Interceptor_TOKEN = "Bearer " + resultBean;
                                finish();
                            }

                            @Override
                            public void onError(String Error) {
                                dismissDialog();
                            }

                        });
            }
        }
    });

    // 跳转登录页
    public BindingCommand goLogin = new BindingCommand(new BindingAction() {
        @Override
        public void call() {
            finish();
            startActivity(LoginActivity.class);
        }

    });
}
