package com.xx.merchanthbh.ui.pwd;

import static me.goldze.mvvmhabit.utils.Utils.Interceptor_TOKEN;

import android.app.Application;
import android.text.TextUtils;

import androidx.annotation.NonNull;
import androidx.databinding.ObservableField;

import com.xx.merchanthbh.data.http.requst.SetPwdRequest;
import com.xx.merchanthbh.ui.login.LoginActivity;

import io.reactivex.rxjava3.disposables.Disposable;
import io.reactivex.rxjava3.functions.Consumer;
import me.goldze.mvvmhabit.base.BaseViewModel;
import me.goldze.mvvmhabit.binding.command.BindingAction;
import me.goldze.mvvmhabit.binding.command.BindingCommand;
import me.goldze.mvvmhabit.http.ApiDisposableObserver;
import me.goldze.mvvmhabit.utils.RxUtils;
import me.goldze.mvvmhabit.utils.ToastUtils;

public class SetPwdViewModel extends BaseViewModel<SetPwdRequest> {
    //密码绑定
    public ObservableField<String> password = new ObservableField<>("");
    //重复密码绑定
    public ObservableField<String> repeatPassword = new ObservableField<>("");

    public SetPwdViewModel(@NonNull Application application) {
        super(application);
    }

    public SetPwdViewModel(@NonNull Application application, SetPwdRequest model) {
        super(application, model);
    }
    // 密码是否满足要求的方法
    private boolean passwordMatchesRequirements(String password) {
        // 使用正则表达式验证密码是否包含至少一个大写字母和一个小写字母
        String regex = "^(?=.*[a-z])(?=.*[A-Z]).+$";
        return password.matches(regex);
    }
    // 触发确认按钮
    public BindingCommand setPwd = new BindingCommand(new BindingAction() {
        @Override
        public void call() {
            if (TextUtils.isEmpty(password.get())) {
                ToastUtils.showShort("请输入登录密码！");
            } else if (password.get().length() < 8 || password.get().length() > 20) {
                ToastUtils.showShort("密码长度8-20位,需要同时包含大小写字母和数字");
            } else if (!passwordMatchesRequirements(password.get())) {
                ToastUtils.showShort("密码长度8-20位,需要同时包含大小写字母和数字");
            }
            else if (TextUtils.isEmpty(repeatPassword.get())) {
                ToastUtils.showShort("请再次输入登录密码！");
            } else if (!password.get().equals(repeatPassword.get())) {
                ToastUtils.showShort("前后密码不一致！");
            } else {
                model.SetPwd( password.get())
                        .compose(RxUtils.schedulersTransformer()) //线程调度
//                        .compose(RxUtils.exceptionTransformer()) // 网络错误的异常转换, 这里可以换成自己的ExceptionHandle
                        .doOnSubscribe(SetPwdViewModel.this)
                        .doOnSubscribe(new Consumer<Disposable>() {
                            @Override
                            public void accept(Disposable disposable) throws Exception {
                                showDialog("正在请求...");
                            }
                        }).subscribe(new ApiDisposableObserver<String>() {
                            @Override
                            public void onSuccess(String resultBean) {
                                //是指token
                                Interceptor_TOKEN = "Bearer " + resultBean;
                                finish();
                                /*待确认!!!!!!!!*/
//                                startActivity(LoginActivity.class);
                                finish();
                            }

                            @Override
                            public void onError(String Error) {
                                dismissDialog();
                            }

                        });
            }
        }
    });
}
