package com.xx.merchanthbh.ui.recruitment;

import static android.app.Activity.RESULT_OK;

import android.app.Activity;
import android.app.Application;
import android.content.ContentResolver;
import android.content.Context;
import android.content.Intent;
import android.database.Cursor;
import android.net.Uri;
import android.provider.MediaStore;
import android.provider.OpenableColumns;
import android.util.Log;
import android.view.View;
import android.widget.Toast;

import androidx.annotation.NonNull;
import androidx.databinding.ObservableField;

import com.xx.merchanthbh.data.http.requst.RecruitmentRequest;
import com.xx.merchanthbh.data.http.respons.Filebean;
import com.xx.merchanthbh.data.http.respons.JobDetailBean;
import com.xx.xxviewlibrary.witget.model.FileBean;

import java.io.File;
import java.io.FileOutputStream;
import java.io.InputStream;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import io.reactivex.rxjava3.disposables.Disposable;
import io.reactivex.rxjava3.functions.Consumer;
import me.goldze.mvvmhabit.base.BaseViewModel;
import me.goldze.mvvmhabit.http.ApiDisposableObserver;
import me.goldze.mvvmhabit.utils.RxUtils;

public class JobDetailViewModel extends BaseViewModel<RecruitmentRequest> {

    /*声明要给接口传参的id*/
    public String businessId = "";
    /*简历获取的bId*/
    public String resumeId = "";
    /*招聘详情获取的bId*/
    public String recruitmentId = "";
    //岗位名称
    public ObservableField<String> postName = new ObservableField<>("");
    //岗位工资
    public ObservableField<String> postWage = new ObservableField<>("");
    //招聘企业
    public ObservableField<String> recruitmentEnterprise = new ObservableField<>("");
    //学历要求 1-硕士及以上 2-本科及以上 3-专科及以上 4-高中及以上 5-初中及以上 6-无
    public ObservableField<String> educationalRequirement = new ObservableField<>("");
    //工作经验 1、1年 2、1-3年 3、3-5年 4、5-7年 5、7-10年 6、10年以上 7、无
    public ObservableField<String> workExperience = new ObservableField<>("");
    //工作地点
    public ObservableField<String> workPlace = new ObservableField<>("");
    //岗位描述
    public ObservableField<String> postDescription = new ObservableField<>("");
    //岗位职责
    public ObservableField<String> postResponsibility = new ObservableField<>("");
    //试用期 默认无
    public ObservableField<String> probationPeriod = new ObservableField<>("");
    //联系方式 1-手机号 2-邮箱 3-座机
    public ObservableField<String> contactInformation = new ObservableField<>("");
    //其他信息
    public ObservableField<String> otherInformation = new ObservableField<>("");


    //招聘类型
    public ObservableField<Integer> submitVisibility = new ObservableField<>(View.GONE);
    public JobDetailViewModel(@NonNull Application application) {
        super(application);
    }

    public JobDetailViewModel(@NonNull Application application, RecruitmentRequest model, Activity activity) {
        super(application, model);
        /*将获取到的activity对象进行赋值*/
        this.activity = activity;

    }

    /*用来接传过来的activity*/
    Activity activity;
    /*用来盛文件*/
    Intent myFileIntent;

    /*投简历*/
    public void submitResume(View view) {
        myFileIntent = new Intent(Intent.ACTION_GET_CONTENT);
        /*任意类型文件*/
        myFileIntent.setType("*/*");
        activity.startActivityForResult(myFileIntent, 10);
    }


    /*运用重写的方法进行点击任意文件的上传接口调用*/
    public void onActivityResult(int requestCode, int resultCode, Intent data) {
        if (requestCode == 10 && resultCode == Activity.RESULT_OK) {
            if (data != null && data.getData() != null) {
                String filePath;
                /*1-获取数据*/
                Uri uri = data.getData();
                /*格式化文件路径*/
                filePath = getFilePathForN(uri, activity);
                if (!filePath.toLowerCase().endsWith(".pdf")) {
                    Toast.makeText(activity, "请选择正确的PDF文件", Toast.LENGTH_SHORT).show();
                    return;
                }
                File file = new File(filePath);
                Log.v("这是我选中获取的文件路径", filePath);
                /*加一个判断条件 只有满足这个条件才执行上传接口*/
                if (!filePath.equals("1")) {
                    model.getResumesList(file)
                            .compose(RxUtils.schedulersTransformer()) //线程调度
                            .doOnSubscribe(JobDetailViewModel.this)
                            .doOnSubscribe(new Consumer<Disposable>() {
                                @Override
                                public void accept(Disposable disposable) throws Exception {
                                }
                            }).subscribe(new ApiDisposableObserver<List<Filebean>>() {
                                @Override
                                public void onSuccess(List<Filebean> resultBean) {
                                    /*给获取的简历id赋值*/
                                    resumeId = resultBean.get(0).getBusinessId();
                                    Log.v("hhh还差最后一步,已经获取到简历id", resumeId);
                                    /**
                                     * 新增应聘记录(简历投递)传参 1-recruitmentId:招聘ID 2-resumeFileId:文件ID
                                     */
                                    model.addRecruitmentList(recruitmentId, resumeId)
                                            .compose(RxUtils.schedulersTransformer()) //线程调度
                                            .doOnSubscribe(JobDetailViewModel.this)
                                            .doOnSubscribe(new Consumer<Disposable>() {
                                                @Override
                                                public void accept(Disposable disposable) throws Exception {
                                                }
                                            }).subscribe(new ApiDisposableObserver<Number>() {
                                                @Override
                                                public void onSuccess(Number resultBean) {
                                                    /*第一次投递简历吐司提示投递成功*/
                                                    Toast.makeText(activity, "投递成功!", Toast.LENGTH_SHORT).show();
                                                }

                                                @Override
                                                public void onError(String Error) {
                                                    dismissDialog();
                                                }


                                            });
                                }

                                @Override
                                public void onError(String Error) {
                                    dismissDialog();
                                }


                            });
                }
            }
        }
    }

    /*对文件进行格式化路径*/
    private static String getFilePathForN(Uri uri, Context context) {
        Uri returnUri = uri;
        Cursor returnCursor = context.getContentResolver().query(returnUri, null, null, null, null);
        /*
         * Get the column indexes of the data in the Cursor,
         *     * move to the first row in the Cursor, get the data,
         *     * and display it.
         * */
        int nameIndex = returnCursor.getColumnIndex(OpenableColumns.DISPLAY_NAME);
        int sizeIndex = returnCursor.getColumnIndex(OpenableColumns.SIZE);
        returnCursor.moveToFirst();
        String name = (returnCursor.getString(nameIndex));
        String size = (Long.toString(returnCursor.getLong(sizeIndex)));
        File file = new File(context.getFilesDir(), name);
        try {
            InputStream inputStream = context.getContentResolver().openInputStream(uri);
            FileOutputStream outputStream = new FileOutputStream(file);
            int read = 0;
            int maxBufferSize = 1 * 1024 * 1024;
            int bytesAvailable = inputStream.available();

            //int bufferSize = 1024;
            int bufferSize = Math.min(bytesAvailable, maxBufferSize);

            final byte[] buffers = new byte[bufferSize];
            while ((read = inputStream.read(buffers)) != -1) {
                outputStream.write(buffers, 0, read);
            }
            Log.e("File Size", "Size " + file.length());
            inputStream.close();
            outputStream.close();
            Log.e("File Path", "Path " + file.getPath());
            Log.e("File Size", "Size " + file.length());
        } catch (Exception e) {
            Log.e("Exception", e.getMessage());
        }
        return file.getPath();
    }


    /**
     * 获取招聘详情
     */
    public void getJobInformationDetailById() {
        model.getJobInformationDetailById(businessId).compose(RxUtils.schedulersTransformer()) //线程调度
                .doOnSubscribe(JobDetailViewModel.this)
                .doOnSubscribe(new Consumer<Disposable>() {
                    @Override
                    public void accept(Disposable disposable) throws Exception {
                    }
                }).subscribe(new ApiDisposableObserver<JobDetailBean>() {
                    @Override
                    public void onSuccess(JobDetailBean resultBean) {
                        /*businessId*/
                        recruitmentId = resultBean.getBusinessId();
                        /*岗位名称*/
                        postName.set(resultBean.getPostName());
                        /*岗位工资*/
                        postWage.set(resultBean.getPostWage());
                        /*招聘企业*/
                        recruitmentEnterprise.set(resultBean.getRecruitmentEnterprise());
                        /*学历要求 1-硕士及以上 2-本科及以上 3-专科及以上 4-高中及以上 5-初中及以上 6-无*/
                        educationalRequirement.set(resultBean.getEducationalRequirement());
                        /*工作经验 1、1年 2、1-3年 3、3-5年 4、5-7年 5、7-10年 6、10年以上 7、无*/
                        workExperience.set(resultBean.getWorkExperience());
                        /*工作地点*/
                        workPlace.set(resultBean.getWorkPlace());
                        /*岗位描述*/
                        postDescription.set(resultBean.getPostDescription());
                        /*岗位职责*/
                        postResponsibility.set(resultBean.getPostResponsibility());
                        /*试用期 默认无*/
                        probationPeriod.set(resultBean.getProbationPeriod());
                        /*联系方式 1-手机号 2-邮箱 3-座机*/
                        contactInformation.set(resultBean.getContactInformation());
                        /*其他信息*/
                        otherInformation.set(resultBean.getOtherInformation());

                        if (resultBean.getRecruitmentType().equals("1"))
                        {
                            submitVisibility.set(View.VISIBLE);
                        }else {
                            submitVisibility.set(View.GONE);
                        }
                        /*学历转换*/
                        /*学历要求 1-硕士及以上 2-本科及以上 3-专科及以上 4-高中及以上 5-初中及以上 6-无*/
                        int educationalReq = Integer.parseInt(resultBean.getEducationalRequirement());
                        Map<String, String> educationalReqMap = new HashMap<>();
                        educationalReqMap.put("1", "硕士及以上");
                        educationalReqMap.put("2", "本科及以上");
                        educationalReqMap.put("3", "专科及以上");
                        educationalReqMap.put("4", "高中及以上");
                        educationalReqMap.put("5", "初中及以上");
                        educationalReqMap.put("6", "无");
                        String educationalReqString = educationalReqMap.put(String.valueOf(educationalReq), "未知");
                        educationalRequirement.set(educationalReqString);


                        /*工作经验转换*/
                        /*工作经验 1-1年 2-1-3年 3-3-5年 4-5-7年 5-7-10年 6-10年以上 7-无*/
                        int workExp = Integer.parseInt(resultBean.getWorkExperience());
                        Map<String, String> workExpMap = new HashMap<>();
                        workExpMap.put("1", "1年");
                        workExpMap.put("2", "1-3年");
                        workExpMap.put("3", "3-5年");
                        workExpMap.put("4", "5-7年");
                        workExpMap.put("5", "7-10年");
                        workExpMap.put("6", "10年以上");
                        workExpMap.put("7", "无");
                        String workExpString = workExpMap.put(String.valueOf(workExp), "未知");
                        workExperience.set(workExpString);


                        /*工作地点转换*/
                        /*工作地点 1-环渤海河西 2-滨海宏达公司*/
                        String workPlaces = resultBean.getWorkPlace();
                        Map<String, String> workPlaceMap = new HashMap<>();
                        workPlaceMap.put("1", "环渤海河西");
                        workPlaceMap.put("2", "滨海宏达公司");
                        String workPlaceString = workPlaceMap.put(String.valueOf(workPlaces), "未知");
                        workPlace.set(workPlaceString);



                        /*联系方式转换*/
                        /*联系方式 1-手机号 2-邮箱 3-座机*/
                      /*  String contactInformations = resultBean.getContactInformation();
                        Map<String, String> contactInformationMap = new HashMap<>();
                        contactInf
ormationMap.put("1", "手机号");
                        contactInformationMap.put("2", "邮箱");
                        contactInformationMap.put("3", "座机");

                        String contactInformationString = contactInformationMap.put(contactInformations, "未知");*/
                        contactInformation.set(resultBean.getContactInformationType());

                    }

                    @Override
                    public void onError(String Error) {

                    }

                });
    }


}
